@@ -45,8 +45,12 @@
 gint
 main (gint argc, gchar **argv)
 {
+	GtkIconTheme *icon_theme;
 	AlarmNotify *alarm_notify_service;
 	UniqueApp *app;
+#ifdef G_OS_WIN32
+	gchar *path;
+#endif
 
 	bindtextdomain (GETTEXT_PACKAGE, EVOLUTION_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -55,6 +59,13 @@ main (gint argc, gchar **argv)
 	g_thread_init (NULL);
 	dbus_g_thread_init ();
 
+#ifdef G_OS_WIN32
+	path = g_build_path (";", _e_get_bindir (), g_getenv ("PATH"), NULL);
+
+	if (!g_setenv ("PATH", path, TRUE))
+		g_warning ("Could not set PATH for Evolution Alarm Notifier");
+#endif
+
 	gtk_init (&argc, &argv);
 
 	app = unique_app_new ("org.gnome.EvolutionAlarmNotify", NULL);
@@ -71,6 +82,9 @@ main (gint argc, gchar **argv)
 	/* Initialize Camel's type system. */
 	camel_object_get_type();
 
+	icon_theme = gtk_icon_theme_get_default ();
+	gtk_icon_theme_append_search_path (icon_theme, EVOLUTION_ICONDIR);
+
 	gtk_main ();
 
 	if (alarm_notify_service != NULL)
