@@ -30,12 +30,11 @@
 #endif
 
 #include <string.h>
-#include <glade/glade.h>
 #include <glib/gi18n.h>
 
-#include <e-util/e-plugin-ui.h>
-#include <e-util/e-util-private.h>
-#include <evolution-shell-component-utils.h>
+#include "e-util/e-binding.h"
+#include "e-util/e-plugin-ui.h"
+#include "e-util/e-util-private.h"
 
 #include "task-page.h"
 #include "task-details-page.h"
@@ -126,15 +125,6 @@ static GtkActionEntry assigned_task_entries[] = {
 	  G_CALLBACK (action_send_options_cb) }
 };
 
-static void
-task_editor_client_changed_cb (TaskEditor *te)
-{
-	ECal *client;
-
-	client = comp_editor_get_client (COMP_EDITOR (te));
-	e_meeting_store_set_e_cal (te->priv->model, client);
-}
-
 static void
 task_editor_model_changed_cb (TaskEditor *te)
 {
@@ -208,6 +198,31 @@ task_editor_dispose (GObject *object)
 	G_OBJECT_CLASS (task_editor_parent_class)->dispose (object);
 }
 
+static void
+task_editor_constructed (GObject *object)
+{
+	TaskEditorPrivate *priv;
+	EShellSettings *shell_settings;
+	EShell *shell;
+
+	priv = TASK_EDITOR_GET_PRIVATE (object);
+
+	shell = comp_editor_get_shell (COMP_EDITOR (object));
+	shell_settings = e_shell_get_shell_settings (shell);
+
+	e_binding_new (
+		object, "client",
+		priv->model, "client");
+
+	e_binding_new (
+		shell_settings, "cal-free-busy-template",
+		priv->model, "free-busy-template");
+
+	e_binding_new (
+		shell_settings, "cal-timezone",
+		priv->model, "timezone");
+}
+
 static void
 task_editor_show_categories (CompEditor *editor,
                              gboolean visible)
@@ -285,6 +300,7 @@ task_editor_class_init (TaskEditorClass *class)
 	object_class = G_OBJECT_CLASS (class);
 	object_class->constructor = task_editor_constructor;
 	object_class->dispose = task_editor_dispose;
+	object_class->constructed = task_editor_constructed;
 
 	editor_class = COMP_EDITOR_CLASS (class);
 	editor_class->help_section = "usage-calendar-todo";
@@ -304,6 +320,7 @@ task_editor_init (TaskEditor *te)
 	CompEditor *editor = COMP_EDITOR (te);
 	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
+	const gchar *id;
 	GError *error = NULL;
 
 	te->priv = TASK_EDITOR_GET_PRIVATE (te);
@@ -346,17 +363,16 @@ task_editor_init (TaskEditor *te)
 
 	ui_manager = comp_editor_get_ui_manager (editor);
 	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, &error);
-	e_plugin_ui_register_manager ("task-editor", ui_manager, te);
+
+	id = "org.gnome.evolution.task-editor";
+	e_plugin_ui_register_manager (ui_manager, id, te);
+	e_plugin_ui_enable_manager (ui_manager, id);
 
 	if (error != NULL) {
 		g_critical ("%s: %s", G_STRFUNC, error->message);
 		g_error_free (error);
 	}
 
-	g_signal_connect (
-		te, "notify::client",
-		G_CALLBACK (task_editor_client_changed_cb), NULL);
-
 	g_signal_connect_swapped (
 		te->priv->model, "row_changed",
 		G_CALLBACK (task_editor_model_changed_cb), te);
@@ -434,7 +450,6 @@ task_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 				e_meeting_attendee_set_edit_level (ia, E_MEETING_ATTENDEE_EDIT_NONE);
 		}
 
-
 		comp_editor_set_group_item (editor, TRUE);
 		priv->assignment_shown = TRUE;
 	}
@@ -463,9 +478,9 @@ task_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gbool
 		ECal *client;
 		gboolean result;
 
-		client = e_meeting_store_get_e_cal (priv->model);
+		client = e_meeting_store_get_client (priv->model);
 		result = itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp,
-				client, NULL, NULL, NULL, strip_alarms);
+				client, NULL, NULL, NULL, strip_alarms, FALSE);
 		g_object_unref (comp);
 
 		if (!result)
@@ -489,13 +504,16 @@ task_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gbool
  * editor could not be created.
  **/
 CompEditor *
-task_editor_new (ECal *client, CompEditorFlags flags)
+task_editor_new (ECal *client,
+                 EShell *shell,
+                 CompEditorFlags flags)
 {
 	g_return_val_if_fail (E_IS_CAL (client), NULL);
+	g_return_val_if_fail (E_IS_SHELL (shell), NULL);
 
 	return g_object_new (
 		TYPE_TASK_EDITOR,
-		"flags", flags, "client", client, NULL);
+		"client", client, "flags", flags, "shell", shell, NULL);
 }
 
 void
