@@ -27,9 +27,6 @@
 
 #include <string.h>
 #include <gtk/gtk.h>
-#include <bonobo/bonobo-control.h>
-#include <bonobo/bonobo-widget.h>
-#include <bonobo/bonobo-exception.h>
 #include <glib/gi18n.h>
 #include <libebook/e-book.h>
 #include <libebook/e-vcard.h>
@@ -120,7 +117,6 @@ e_meeting_list_view_class_init (EMeetingListViewClass *klass)
 			      G_TYPE_POINTER);
 }
 
-
 static void
 add_section (ENameSelector *name_selector, const gchar *name)
 {
@@ -281,7 +277,6 @@ e_meeting_list_view_remove_attendee_from_name_selector (EMeetingListView *view,
 		const gchar *attendee = NULL;
 		EDestination *des = l->data;
 
-
 		if (e_destination_is_evolution_list (des)) {
 			GList *l, *dl;
 
@@ -363,6 +358,7 @@ attendee_edited_cb (GtkCellRenderer *renderer, const gchar *path, GList *address
 	if (g_list_length (addresses) > 1) {
 		EMeetingAttendee *attendee;
 		GList *l, *m;
+		gboolean can_remove = TRUE;
 
 		for (l = addresses, m = names; l && m; l = l->next, m = m->next) {
 			gchar *name = m->data, *email = l->data;
@@ -370,8 +366,12 @@ attendee_edited_cb (GtkCellRenderer *renderer, const gchar *path, GList *address
 			if (!((name && *name) || (email && *email)))
 					continue;
 
-			if (e_meeting_store_find_attendee (model, email, NULL) != NULL)
+			attendee = e_meeting_store_find_attendee (model, email, NULL);
+			if (attendee != NULL) {
+				if (attendee == existing_attendee)
+					can_remove = FALSE;
 				continue;
+			}
 
 			attendee = e_meeting_store_add_attendee_with_defaults (model);
 			e_meeting_attendee_set_address (attendee, g_strdup_printf ("MAILTO:%s", (gchar *)l->data));
@@ -387,7 +387,7 @@ attendee_edited_cb (GtkCellRenderer *renderer, const gchar *path, GList *address
 			e_meeting_list_view_add_attendee_to_name_selector (E_MEETING_LIST_VIEW (view), attendee);
 		}
 
-		if (existing_attendee) {
+		if (existing_attendee && can_remove) {
 			removed = TRUE;
 			e_meeting_list_view_remove_attendee_from_name_selector (E_MEETING_LIST_VIEW (view),
 						existing_attendee);
@@ -398,7 +398,7 @@ attendee_edited_cb (GtkCellRenderer *renderer, const gchar *path, GList *address
 		gchar *name = names->data, *email = addresses->data;
 		gint existing_row;
 
-		if (!((name && *name) || (email && *email)) || ((e_meeting_store_find_attendee (model, email, &existing_row) != NULL) && existing_row != row)){
+		if (!((name && *name) || (email && *email)) || ((e_meeting_store_find_attendee (model, email, &existing_row) != NULL) && existing_row != row)) {
 			if (existing_attendee) {
 				removed = TRUE;
 				e_meeting_list_view_remove_attendee_from_name_selector (E_MEETING_LIST_VIEW (view),
@@ -473,7 +473,6 @@ attendee_editing_canceled_cb (GtkCellRenderer *renderer, GtkTreeView *view)
 	gtk_tree_path_free (path);
 }
 
-
 static void
 type_edited_cb (GtkCellRenderer *renderer, const gchar *path, const gchar *text, GtkTreeView *view)
 {
@@ -661,7 +660,6 @@ row_activated_cb (GtkTreeSelection *selection, EMeetingListView *view)
 
        priv = view->priv;
 
-
        if (!(paths = gtk_tree_selection_get_selected_rows (selection, &model)))
                return;
        if (g_list_length (paths) > 1)
@@ -694,7 +692,6 @@ row_activated_cb (GtkTreeSelection *selection, EMeetingListView *view)
 
 }
 
-
 EMeetingListView *
 e_meeting_list_view_new (EMeetingStore *store)
 {
@@ -779,7 +776,7 @@ process_section (EMeetingListView *view, GList *destinations, icalparameter_role
 				gchar *uri = e_contact_get (contact, E_CONTACT_BOOK_URI);
 
 				dialog = e_name_selector_peek_dialog (view->priv->name_selector);
-				c_store = dialog->name_selector_model->contact_store;
+				c_store = e_name_selector_dialog_peek_model (dialog)->contact_store;
 				books = e_contact_store_get_books (c_store);
 
 				for (l = books; l; l = l->next) {
@@ -835,7 +832,7 @@ process_section (EMeetingListView *view, GList *destinations, icalparameter_role
 			name = e_destination_get_name (dest);
 
 			/* Get the field as attendee from the backend */
-			if (e_cal_get_ldap_attribute (e_meeting_store_get_e_cal (priv->store),
+			if (e_cal_get_ldap_attribute (e_meeting_store_get_client (priv->store),
 						      &attr, NULL)) {
 				/* FIXME this should be more general */
 				if (!g_ascii_strcasecmp (attr, "icscalendar")) {
@@ -863,7 +860,6 @@ process_section (EMeetingListView *view, GList *destinations, icalparameter_role
 			if (contact)
 				fburi = e_contact_get (contact, E_CONTACT_FREEBUSY_URL);
 
-
 			if (e_meeting_store_find_attendee (priv->store, attendee, NULL) == NULL) {
 				EMeetingAttendee *ia = e_meeting_store_add_attendee_with_defaults (priv->store);
 
@@ -1003,4 +999,3 @@ e_meeting_list_view_set_name_selector (EMeetingListView *lview, ENameSelector *n
 	priv->name_selector = g_object_ref (name_selector);
 }
 
-
