@@ -1,29 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
-/*
- * Author :
- *  Damon Chaplin <damon@ximian.com>
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
- */
-
 /*
  * Lays out events for the Week & Month views of the calendar. It is also
  * used for printing.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #include <config.h>
@@ -50,7 +45,6 @@ static gint e_week_view_find_span_end	(gboolean	 multi_week_view,
 					 gint		 display_start_day,
 					 gint		 day);
 
-
 GArray*
 e_week_view_layout_events	(GArray		*events,
 				 GArray		*old_spans,
@@ -113,7 +107,6 @@ e_week_view_layout_events	(GArray		*events,
 	return spans;
 }
 
-
 static void
 e_week_view_layout_event	(EWeekViewEvent	*event,
 				 guint8		*grid,
@@ -196,7 +189,9 @@ e_week_view_layout_event	(EWeekViewEvent	*event,
 			span.background_item = NULL;
 			span.text_item = NULL;
 			if (event->num_spans > span_num) {
-				old_span = &g_array_index (old_spans, EWeekViewEventSpan, event->spans_index + span_num);
+				old_span = &g_array_index (
+					old_spans, EWeekViewEventSpan,
+					event->spans_index + span_num);
 				span.background_item = old_span->background_item;
 				span.text_item = old_span->text_item;
 				old_span->background_item = NULL;
@@ -216,7 +211,6 @@ e_week_view_layout_event	(EWeekViewEvent	*event,
 	event->num_spans = num_spans;
 }
 
-
 /* Finds the day containing the given time.
    If include_midnight_in_prev_day is TRUE then if the time exactly
    matches the start of a day the previous day is returned. This is useful
@@ -246,7 +240,6 @@ e_week_view_find_day		(time_t		 time_to_find,
 	g_return_val_if_reached (days_shown);
 }
 
-
 /* This returns the last possible day in the same span as the given day.
    A span is all the days which are displayed next to each other from left to
    right. In the week view all spans are only 1 day, since Tuesday is below
@@ -284,7 +277,6 @@ e_week_view_find_span_end	(gboolean	 multi_week_view,
 	}
 }
 
-
 void
 e_week_view_layout_get_day_position	(gint		 day,
 					 gboolean	 multi_week_view,
@@ -337,10 +329,17 @@ e_week_view_layout_get_day_position	(gint		 day,
 		}
 	} else {
 		#define wk(x) ( ( working_days & (days [ ((x) + display_start_day) % 7 ]) ) ? 1 : 0)
-		CalWeekdays days [] = {CAL_MONDAY, CAL_TUESDAY, CAL_WEDNESDAY, CAL_THURSDAY, CAL_FRIDAY, CAL_SATURDAY, CAL_SUNDAY};
+		CalWeekdays days[] = {
+			CAL_MONDAY,
+			CAL_TUESDAY,
+			CAL_WEDNESDAY,
+			CAL_THURSDAY,
+			CAL_FRIDAY,
+			CAL_SATURDAY,
+			CAL_SUNDAY };
 		CalWeekdays working_days;
-		int arr[4] = {1, 1, 1, 1};
-		int edge, i, wd, m, M;
+		gint arr[4] = {1, 1, 1, 1};
+		gint edge, i, wd, m, M;
 		gboolean any = TRUE;
 
 		g_return_if_fail (day < 7);
@@ -408,7 +407,6 @@ e_week_view_layout_get_day_position	(gint		 day,
 	}
 }
 
-
 /* Returns TRUE if the event span is visible or FALSE if it isn't.
    It also returns the number of days of the span that are visible.
    Usually this can easily be determined by the start & end days and row of
@@ -437,7 +435,7 @@ e_week_view_layout_get_span_position	(EWeekViewEvent *event,
 	if (span->row >= rows_per_compressed_cell) {
 		if (multi_week_view) {
 			if (compress_weekend) {
-				/* If it ends on a Saturday and is 1 day long
+				/* If it ends on a Saturday and is 1 day glong
 				   we skip it, else we shorten it. If it ends
 				   on a Sunday it must be 1 day long and we
 				   skip it. */
@@ -453,10 +451,13 @@ e_week_view_layout_get_span_position	(EWeekViewEvent *event,
 			}
 		} else {
 			gint day_x, day_y, rows = 0;
-			e_week_view_layout_get_day_position (end_day_of_week, multi_week_view, 1, display_start_day, compress_weekend,
-								&day_x, &day_y, &rows);
+			e_week_view_layout_get_day_position (
+				end_day_of_week, multi_week_view, 1,
+				display_start_day, compress_weekend,
+				&day_x, &day_y, &rows);
 
-			if (((rows / 2) * rows_per_cell) + ((rows % 2) * rows_per_compressed_cell) <= span->row)
+			if (((rows / 2) * rows_per_cell) + ((rows % 2) *
+				rows_per_compressed_cell) <= span->row)
 				return FALSE;
 		}
 	}
