@@ -132,7 +132,7 @@ get_font_size (PangoFontDescription *font)
 #define DAY_VIEW_MIN_ROWS_IN_TOP_DISPLAY	2
 
 /* The row height for long events in the day view. */
-#define DAY_VIEW_ROW_HEIGHT		20
+#define DAY_VIEW_ROW_HEIGHT		14
 
 /* The minutes per row in the day view printout. */
 #define DAY_VIEW_MINS_PER_ROW		30
@@ -194,8 +194,8 @@ struct psinfo
 	gint month;
 	gboolean compress_weekend;
 	gboolean use_24_hour_format;
-	double row_height;
-	double header_row_height;
+	gdouble row_height;
+	gdouble header_row_height;
 };
 
 /* Convenience function to help the transition to timezone functions.
@@ -223,10 +223,10 @@ convert_timet_to_struct_tm (time_t time, icaltimezone *zone)
 	return &my_tm;
 }
 
-/* Fills the 42-element days array with the day numbers for the specified month.  Slots outside the
- * bounds of the month are filled with zeros.  The starting and ending indexes of the days are
- * returned in the start and end arguments.
- */
+/* Fills the 42-element days array with the day numbers for the specified
+ * month.  Slots outside the bounds of the month are filled with zeros.
+ * The starting and ending indexes of the days are returned in the start
+ * and end arguments. */
 static void
 build_month (gint month, gint year, gint *days, gint *start, gint *end)
 {
@@ -454,7 +454,7 @@ print_text_size (GtkPrintContext *context, const gchar *text,
                  gdouble y1, gdouble y2)
 {
 	PangoFontDescription *font;
-	double w;
+	gdouble w;
 
 	font = get_font_for_size (ABS (y2 - y1) * 0.5, PANGO_WEIGHT_NORMAL);
 	w = print_text (context, font, text, alignment, x1, x2, y1, y2);
@@ -470,7 +470,7 @@ print_text_size_bold (GtkPrintContext *context, const gchar *text,
                       gdouble y1, gdouble y2)
 {
 	PangoFontDescription *font;
-	double w;
+	gdouble w;
 
 	font = get_font_for_size (ABS (y2 - y1) * 0.5, PANGO_WEIGHT_BOLD);
 	w = print_text (context, font, text, alignment, x1, x2, y1, y2);
@@ -485,7 +485,7 @@ titled_box (GtkPrintContext *context, const gchar *text,
             gdouble *x1, gdouble *y1, gdouble *x2, gdouble *y2,
 	    gdouble linewidth)
 {
-	double size;
+	gdouble size;
 
 	size = get_font_size (font);
 	print_border (context, *x1, *x2, *y1, *y1 + size * 1.4, linewidth, 0.9);
@@ -554,7 +554,10 @@ format_date(time_t time, gint flags, gchar *buffer, gint bufflen)
 }
 
 static gboolean
-instance_cb (ECalComponent *comp, time_t instance_start, time_t instance_end, gpointer data)
+instance_cb (ECalComponent *comp,
+             time_t instance_start,
+             time_t instance_end,
+             gpointer data)
 {
 
 	gboolean *found = ((ECalModelGenerateInstancesData *) data)->cb_data;
@@ -581,9 +584,9 @@ print_month_small (GtkPrintContext *context, GnomeCalendar *gcal, time_t month,
 	gint day, weekday, week_start_day;
 	gchar buf[100];
 	struct tm tm;
-	double font_size, max_font_size;
-	double header_size, col_width, row_height, text_xpad, w;
-	double cell_top, cell_bottom, cell_left, cell_right, text_right;
+	gdouble font_size;
+	gdouble header_size, col_width, row_height, text_xpad, w;
+	gdouble cell_top, cell_bottom, cell_left, cell_right, text_right;
 
 	/* Translators: These are workday abbreviations, e.g. Su=Sunday and Th=thursday */
 	const gchar *daynames[] =
@@ -614,14 +617,6 @@ print_month_small (GtkPrintContext *context, GnomeCalendar *gcal, time_t month,
 	   rough guess of just under the height of each row. */
 	font_size = row_height;
 
-	/* Check that it isn't going to be too wide. The characters are about
-	   twice as high as they are wide, but we need to fit two characters
-	   into each cell, so we don't want to go over col_width. */
-	max_font_size = col_width * 0.65;
-
-	/* Why calculate this if we're not using it? */
-	font_size = row_height;
-
 	/* get month days */
 	tm = *convert_timet_to_struct_tm (month, zone);
 	build_month (tm.tm_mon, tm.tm_year + 1900, days, NULL, NULL);
@@ -725,7 +720,9 @@ bound_text (GtkPrintContext *context,
 
 	pango_layout_get_size (layout, &layout_width, &layout_height);
 
-	if (last_page_start && y1 + pango_units_to_double (layout_height) > y2 + (*last_page_start)) {
+	if (last_page_start &&
+		y1 + pango_units_to_double (layout_height) >
+		y2 + (*last_page_start)) {
 		/* draw this on new page */
 		if (pages)
 			*pages = *pages + 1;
@@ -762,14 +759,14 @@ print_day_background (GtkPrintContext *context, GnomeCalendar *gcal,
 		      double left, double right, double top, double bottom)
 {
 	PangoFontDescription *font_hour, *font_minute;
-	double yinc, y;
-	double width = DAY_VIEW_TIME_COLUMN_WIDTH;
-	double font_size, max_font_size, hour_font_size, minute_font_size;
+	gdouble yinc, y;
+	gdouble width = DAY_VIEW_TIME_COLUMN_WIDTH;
+	gdouble font_size, max_font_size, hour_font_size, minute_font_size;
 	gchar buf[20];
 	const gchar *minute;
 	gboolean use_24_hour;
 	gint i, hour, row;
-	double hour_minute_x;
+	gdouble hour_minute_x;
 	cairo_t *cr;
 
 	/* Fill the time column in light-gray. */
@@ -1041,7 +1038,9 @@ print_attendees (GtkPrintContext *context, PangoFontDescription *font, cairo_t *
 				cairo_show_page (cr);
 			}
 
-			top = bound_text (context, font, text->str, -1, left + 40.0, top, right, bottom, FALSE, NULL, pages);
+			top = bound_text (
+				context, font, text->str, -1, left + 40.0,
+				top, right, bottom, FALSE, NULL, pages);
 
 			g_string_free (text, TRUE);
 		}
@@ -1075,17 +1074,23 @@ get_summary_with_location (icalcomponent *icalcomp)
 }
 
 static void
-print_day_long_event (GtkPrintContext *context, PangoFontDescription *font,
-		      double left, double right, double top, double bottom,
-		      double row_height, EDayViewEvent *event,
-		      struct pdinfo *pdi, ECalModel *model)
+print_day_long_event (GtkPrintContext *context,
+                      PangoFontDescription *font,
+                      gdouble left,
+                      gdouble right,
+                      gdouble top,
+                      gdouble bottom,
+                      gdouble row_height,
+                      EDayViewEvent *event,
+                      struct pdinfo *pdi,
+                      ECalModel *model)
 {
-	double x1, x2, y1, y2;
-	double left_triangle_width = -1.0, right_triangle_width = -1.0;
+	gdouble x1, x2, y1, y2;
+	gdouble left_triangle_width = -1.0, right_triangle_width = -1.0;
 	gchar *text;
 	gchar buffer[32];
 	struct tm date_tm;
-	double red, green, blue;
+	gdouble red, green, blue;
 
 	/* If the event starts before the first day being printed, draw a
 	   triangle. (Note that I am assuming we are just showing 1 day at
@@ -1100,10 +1105,11 @@ print_day_long_event (GtkPrintContext *context, PangoFontDescription *font,
 
 	x1 = left + 10;
 	x2 = right - 10;
-	y1 = top + event->start_row_or_col * row_height + 4;
-	y2 = y1 + row_height-7;
+	y1 = top + event->start_row_or_col * row_height + 1;
+	y2 = y1 + row_height - 1;
 	red = green = blue = 0.95;
-	e_cal_model_get_rgb_color_for_component (model, event->comp_data, &red, &green, &blue);
+	e_cal_model_get_rgb_color_for_component (
+		model, event->comp_data, &red, &green, &blue);
 	print_border_with_triangles (context, x1, x2, y1, y2, 0.5, red, green, blue,
 				     left_triangle_width,
 				     right_triangle_width);
@@ -1159,12 +1165,12 @@ print_day_event (GtkPrintContext *context, PangoFontDescription *font,
 		 double left, double right, double top, double bottom,
 		 EDayViewEvent *event, struct pdinfo *pdi, ECalModel *model)
 {
-	double x1, x2, y1, y2, col_width, row_height;
+	gdouble x1, x2, y1, y2, col_width, row_height;
 	gint start_offset, end_offset, start_row, end_row;
 	gchar *text, start_buffer[32], end_buffer[32];
 	gboolean display_times = FALSE;
 	struct tm date_tm;
-	double red, green, blue;
+	gdouble red, green, blue;
 
 	if ((event->start_minute >= pdi->end_minute_offset)
 	    || (event->end_minute <= pdi->start_minute_offset))
@@ -1177,7 +1183,8 @@ print_day_event (GtkPrintContext *context, PangoFontDescription *font,
 	start_row = MAX (0, start_row);
 	end_row = (end_offset - 1) / pdi->mins_per_row;
 	end_row = MIN (pdi->rows - 1, end_row);
-	col_width = (right - left) / pdi->cols_per_row[event->start_minute / pdi->mins_per_row];
+	col_width = (right - left) /
+		pdi->cols_per_row[event->start_minute / pdi->mins_per_row];
 
 	if (start_offset != start_row * pdi->mins_per_row
 	    || end_offset != (end_row + 1) * pdi->mins_per_row)
@@ -1195,7 +1202,8 @@ print_day_event (GtkPrintContext *context, PangoFontDescription *font,
 #endif
 
 	red = green = blue = 0.95;
-	e_cal_model_get_rgb_color_for_component (model, event->comp_data, &red, &green, &blue);
+	e_cal_model_get_rgb_color_for_component (
+		model, event->comp_data, &red, &green, &blue);
 	print_border_rgb (context, x1, x2, y1, y2, 1.0, red, green, blue);
 
 	text = get_summary_with_location (event->comp_data->icalcomp);
@@ -1242,9 +1250,11 @@ print_day_details (GtkPrintContext *context, GnomeCalendar *gcal, time_t whence,
 	time_t start, end;
 	struct pdinfo pdi;
 	gint rows_in_top_display, i;
-	double font_size, max_font_size;
+	gdouble font_size, max_font_size;
 	cairo_t *cr;
 	GdkPixbuf *pixbuf = NULL;
+#define LONG_DAY_EVENTS_TOP_SPACING 4
+#define LONG_DAY_EVENTS_BOTTOM_SPACING 2
 
 	ECalModel *model = gnome_calendar_get_model (gcal);
 
@@ -1315,8 +1325,10 @@ print_day_details (GtkPrintContext *context, GnomeCalendar *gcal, time_t whence,
 
 	for (i = 0; i < rows_in_top_display && i < pdi.long_events->len; i++) {
 		event = &g_array_index (pdi.long_events, EDayViewEvent, i);
-		print_day_long_event (context, font, left, right, top, bottom,
-				      DAY_VIEW_ROW_HEIGHT, event, &pdi, model);
+		print_day_long_event (
+			context, font, left, right,
+			top + LONG_DAY_EVENTS_TOP_SPACING, bottom,
+			DAY_VIEW_ROW_HEIGHT, event, &pdi, model);
 	}
 
 	if (rows_in_top_display < pdi.long_events->len) {
@@ -1324,8 +1336,6 @@ print_day_details (GtkPrintContext *context, GnomeCalendar *gcal, time_t whence,
 		cairo_t *cr = gtk_print_context_get_cairo_context (context);
 		gint x, y;
 
-		rows_in_top_display++;
-
 		if (!pixbuf) {
 			const gchar **xpm = (const gchar **)jump_xpm;
 
@@ -1339,9 +1349,11 @@ print_day_details (GtkPrintContext *context, GnomeCalendar *gcal, time_t whence,
 
 		/* Right align - 10 comes from print_day_long_event  too */
 		x = right - gdk_pixbuf_get_width (pixbuf) * 0.5 - 10;
-		/* Placing '...' at mid height. 4 and 7 constant come from print_day_long_event
-		   (offsets used to place events boxes in their respective cells) */
-		y = top + DAY_VIEW_ROW_HEIGHT * i + (DAY_VIEW_ROW_HEIGHT - 4 - 7) * 0.5;
+		/* Placing '...' over the last all day event entry printed. '-1 -1' comes
+			from print_long_day_event (top/bottom spacing in each cell) */
+		y = top + LONG_DAY_EVENTS_TOP_SPACING
+			+ DAY_VIEW_ROW_HEIGHT * (i - 1)
+			+ (DAY_VIEW_ROW_HEIGHT - 1 - 1) * 0.5;
 
 		cairo_save (cr);
 		cairo_scale (cr, 0.5, 0.5);
@@ -1357,12 +1369,16 @@ print_day_details (GtkPrintContext *context, GnomeCalendar *gcal, time_t whence,
 	cr = gtk_print_context_get_cairo_context (context);
 
 	cairo_set_source_rgb (cr, 0, 0, 0);
-		print_border (context, left, right,
-		      top, top + rows_in_top_display * DAY_VIEW_ROW_HEIGHT - 4,
-		      1.0, -1.0);
+	print_border (
+		context, left, right,
+		top, top + rows_in_top_display * DAY_VIEW_ROW_HEIGHT +
+		LONG_DAY_EVENTS_TOP_SPACING + LONG_DAY_EVENTS_BOTTOM_SPACING,
+		1.0, -1.0);
 
 	/* Adjust the area containing the main display. */
-	top += rows_in_top_display * DAY_VIEW_ROW_HEIGHT - 2;
+	top += rows_in_top_display * DAY_VIEW_ROW_HEIGHT
+		+ LONG_DAY_EVENTS_TOP_SPACING
+		+ LONG_DAY_EVENTS_BOTTOM_SPACING;
 
 	/* Draw the borders, lines, and times down the left. */
 	print_day_background (context, gcal, whence, &pdi,
@@ -1423,7 +1439,7 @@ print_week_long_event (GtkPrintContext *context, PangoFontDescription *font,
 		       EWeekViewEvent *event, EWeekViewEventSpan *span,
 		       gchar *text, double red, double green, double blue)
 {
-	double left_triangle_width = -1.0, right_triangle_width = -1.0;
+	gdouble left_triangle_width = -1.0, right_triangle_width = -1.0;
 	struct tm date_tm;
 	gchar buffer[32];
 
@@ -1437,9 +1453,9 @@ print_week_long_event (GtkPrintContext *context, PangoFontDescription *font,
 	if (event->end > psi->day_starts[span->start_day + span->num_days])
 		right_triangle_width = 4;
 
-	print_border_with_triangles (context, x1, x2, y1, y1 + row_height, 0.0, red, green, blue,
-				     left_triangle_width,
-				     right_triangle_width);
+	print_border_with_triangles (
+		context, x1, x2, y1, y1 + row_height, 0.0, red, green, blue,
+		left_triangle_width, right_triangle_width);
 
 	/* If the event starts after the first day being printed, we need to
 	   print the start time. */
@@ -1456,7 +1472,9 @@ print_week_long_event (GtkPrintContext *context, PangoFontDescription *font,
 				    buffer, sizeof (buffer));
 
 		x1 += 4;
-		x1 += print_text_size (context, buffer, PANGO_ALIGN_LEFT, x1, x2, y1, y1 + row_height);
+		x1 += print_text_size (
+			context, buffer, PANGO_ALIGN_LEFT,
+			x1, x2, y1, y1 + row_height);
 	}
 
 	/* If the event ends before the end of the last day being printed,
@@ -1474,7 +1492,9 @@ print_week_long_event (GtkPrintContext *context, PangoFontDescription *font,
 				    buffer, sizeof (buffer));
 
 		x2 -= 4;
-		x2 -= print_text_size (context, buffer, PANGO_ALIGN_RIGHT, x1, x2, y1, y1 + row_height);
+		x2 -= print_text_size (
+			context, buffer, PANGO_ALIGN_RIGHT,
+			x1, x2, y1, y1 + row_height);
 	}
 
 	x1 += 4;
@@ -1503,7 +1523,9 @@ print_week_day_event (GtkPrintContext *context, PangoFontDescription *font,
 	e_time_format_time (&date_tm, psi->use_24_hour_format, FALSE,
 			    buffer, sizeof (buffer));
 	print_rectangle (context, x1, y1, x2 - x1, row_height, red, green, blue);
-	x1 += print_text_size (context, buffer, PANGO_ALIGN_LEFT, x1, x2, y1, y1 + row_height) + 4;
+	x1 += print_text_size (
+		context, buffer, PANGO_ALIGN_LEFT,
+		x1, x2, y1, y1 + row_height) + 4;
 
 	if (psi->weeks_shown <= 2) {
 		date_tm.tm_hour = event->end_minute / 60;
@@ -1513,10 +1535,14 @@ print_week_day_event (GtkPrintContext *context, PangoFontDescription *font,
 				    buffer, sizeof (buffer));
 
 		print_rectangle (context, x1, y1, x2 - x1, row_height, red, green, blue);
-		x1 += print_text_size (context, buffer, PANGO_ALIGN_LEFT, x1, x2, y1, y1 + row_height) + 4;
+		x1 += print_text_size (
+			context, buffer, PANGO_ALIGN_LEFT,
+			x1, x2, y1, y1 + row_height) + 4;
 	}
 
-	print_text_size (context, text, PANGO_ALIGN_LEFT, x1, x2, y1, y1 + row_height);
+	print_text_size (
+		context, text, PANGO_ALIGN_LEFT,
+		x1, x2, y1, y1 + row_height);
 }
 
 static void
@@ -1531,8 +1557,8 @@ print_week_event (GtkPrintContext *context, PangoFontDescription *font,
 	gint span_num;
 	gchar *text;
 	gint num_days, start_x, start_y, start_h, end_x, end_y, end_h;
-	double x1, x2, y1, y2;
-	double red, green, blue;
+	gdouble x1, x2, y1;
+	gdouble red, green, blue;
 	GdkPixbuf *pixbuf = NULL;
 
 	text = get_summary_with_location (event->comp_data->icalcomp);
@@ -1577,12 +1603,12 @@ print_week_event (GtkPrintContext *context, PangoFontDescription *font,
 			y1 = top + start_y * cell_height
 				 + psi->header_row_height
 				 + span->row * (psi->row_height + 2);
-			y2 = y1 + psi->row_height * 0.5;
 
 			red = .9;
 			green = .9;
 			blue = .9;
-			e_cal_model_get_rgb_color_for_component (model, event->comp_data, &red, &green, &blue);
+			e_cal_model_get_rgb_color_for_component (
+				model, event->comp_data, &red, &green, &blue);
 			if (print_is_one_day_week_event (event, span,
 							 psi->day_starts)) {
 				print_week_day_event (context, font, psi,
@@ -1613,7 +1639,10 @@ print_week_event (GtkPrintContext *context, PangoFontDescription *font,
 
 				if (end_day_of_week == 5 || end_day_of_week == 6) {
 					/* Sat or Sun */
-					y1 = y1 + (psi->rows_per_compressed_cell - psi->rows_per_cell) * psi->row_height - 3.0;
+					y1 = top + start_y * cell_height
+						 + psi->header_row_height
+						 + psi->rows_per_compressed_cell * (psi->row_height + 2);
+
 				}
 			}
 
@@ -1654,7 +1683,7 @@ print_week_view_background (GtkPrintContext *context,
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
 	struct tm tm;
 	gint day, day_x, day_y, day_h;
-	double x1, x2, y1, y2, font_size, fillcolor;
+	gdouble x1, x2, y1, y2, font_size, fillcolor;
 	const gchar *format_string;
 	gchar buffer[128];
 	cairo_t *cr;
@@ -1743,7 +1772,7 @@ print_week_summary_cb (ECalComponent *comp,
 	start_tt = icaltime_from_timet_with_zone (start, FALSE, zone);
 	end_tt = icaltime_from_timet_with_zone (end, FALSE, zone);
 
-	event.comp_data = e_cal_model_copy_component_data (mdata->comp_data);
+	event.comp_data = g_object_ref (mdata->comp_data);
 
 	event.start = start;
 	event.end = end;
@@ -1773,7 +1802,7 @@ print_week_summary (GtkPrintContext *context, GnomeCalendar *gcal,
 	gint rows_per_day[E_WEEK_VIEW_MAX_WEEKS * 7], day, event_num;
 	GArray *spans;
 	PangoFontDescription *font;
-	double cell_width, cell_height;
+	gdouble cell_width, cell_height;
 	ECalModel *model = gnome_calendar_get_model (gcal);
 
 	psi.days_shown = weeks_shown * 7;
@@ -1836,7 +1865,7 @@ print_week_summary (GtkPrintContext *context, GnomeCalendar *gcal,
 	psi.rows_per_cell = ((cell_height * 2) - psi.header_row_height)
 		/ (psi.row_height + 2);
 	psi.rows_per_compressed_cell = (cell_height - psi.header_row_height)
-		/ psi.row_height;
+		/ (psi.row_height + 2);
 
 	font = get_font_for_size (font_size, PANGO_WEIGHT_NORMAL);
 	/* Draw the grid and the day names/numbers. */
@@ -1854,7 +1883,7 @@ print_week_summary (GtkPrintContext *context, GnomeCalendar *gcal,
 	/* Free everything. */
 	for (event_num = 0; event_num < psi.events->len; event_num++) {
 		event = &g_array_index (psi.events, EWeekViewEvent, event_num);
-		e_cal_model_free_component_data (event->comp_data);
+		g_object_unref (event->comp_data);
 	}
 	g_array_free (psi.events, TRUE);
 	g_array_free (spans, TRUE);
@@ -1868,7 +1897,7 @@ print_year_summary (GtkPrintContext *context, GnomeCalendar *gcal, time_t whence
 		    gint morerows)
 {
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
-	double row_height, col_width, l, r, t, b;
+	gdouble row_height, col_width, l, r, t, b;
 	time_t now;
 	gint col, row, rows, cols;
 
@@ -1918,7 +1947,7 @@ print_month_summary (GtkPrintContext *context, GnomeCalendar *gcal, time_t whenc
 	PangoFontDescription *font;
 	gboolean compress_weekend;
 	gint columns, col, weekday, month;
-	double font_size, cell_width, x1, x2, y1, y2;
+	gdouble font_size, cell_width, x1, x2, y1, y2;
 
 	weekday = calendar_config_get_week_start_day ();
 	compress_weekend = calendar_config_get_compress_weekend ();
@@ -1989,7 +2018,7 @@ print_todo_details (GtkPrintContext *context, GnomeCalendar *gcal,
 {
 #if 0  /* KILL-BONOBO */
 	PangoFontDescription *font_summary;
-	double y, yend, x, xend;
+	gdouble y, yend, x, xend;
 	struct icaltimetype *tt;
 	ECalendarTable *task_pad;
 	ETable *table;
@@ -2030,7 +2059,8 @@ print_todo_details (GtkPrintContext *context, GnomeCalendar *gcal,
 			continue;
 
 		comp = e_cal_component_new ();
-		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (comp_data->icalcomp));
+		e_cal_component_set_icalcomponent (
+			comp, icalcomponent_new_clone (comp_data->icalcomp));
 
 		e_cal_component_get_summary (comp, &summary);
 		if (!summary.value) {
@@ -2085,9 +2115,8 @@ print_day_view (GtkPrintContext *context, GnomeCalendar *gcal, time_t date)
 	GtkPageSetup *setup;
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
 	gint i, days = 1;
-	double todo, l;
+	gdouble todo, l;
 	gchar buf[100];
-	cairo_t *cr;
 	gdouble width, height;
 
 	setup = gtk_print_context_get_page_setup (context);
@@ -2098,8 +2127,6 @@ print_day_view (GtkPrintContext *context, GnomeCalendar *gcal, time_t date)
 	for (i = 0; i < days; i++) {
 		todo = width * 0.75;
 
-		cr = gtk_print_context_get_cairo_context (context);
-
 		/* Print the main view with all the events in. */
 		print_day_details (context, gcal, date,
 				   0.0, todo - 2.0, HEADER_HEIGHT,
@@ -2151,7 +2178,7 @@ print_week_view (GtkPrintContext *context, GnomeCalendar *gcal, time_t date)
 {
 	GtkPageSetup *setup;
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
-	double l;
+	gdouble l;
 	gchar buf[100];
 	time_t when;
 	gint week_start_day;
@@ -2226,7 +2253,7 @@ print_month_view (GtkPrintContext *context, GnomeCalendar *gcal, time_t date)
 	icaltimezone *zone = calendar_config_get_icaltimezone ();
 	gchar buf[100];
 	gdouble width, height;
-	double l;
+	gdouble l;
 
 	setup = gtk_print_context_get_page_setup (context);
 
@@ -2502,10 +2529,10 @@ print_comp_draw_real (GtkPrintOperation *operation,
 
 	const gchar *title, *categories, *location;
 	gchar *categories_string, *location_string, *summary_string;
-	double header_size;
+	gdouble header_size;
 	cairo_t *cr;
 	gdouble width, height, page_start;
-	double top;
+	gdouble top;
 	gint pages = 1;
 
 	setup = gtk_print_context_get_page_setup (context);
@@ -2515,7 +2542,8 @@ print_comp_draw_real (GtkPrintOperation *operation,
 
 	top = 0.0;
 
-	/* either draw only the right page or do not draw anything when calculating number of pages */
+	/* Either draw only the right page or do not draw
+	 * anything when calculating number of pages. */
 	if (page_nr != -1)
 		top = top - ((page_nr) * height);
 	else
@@ -2583,10 +2611,14 @@ print_comp_draw_real (GtkPrintOperation *operation,
 
 	/* Attendees */
 	if ((page_nr == 0) && e_cal_component_has_attendees (comp)) {
-		top = bound_text (context, font, _("Attendees: "), -1, 0.0, top, width, height, FALSE, &page_start, &pages);
+		top = bound_text (
+			context, font, _("Attendees: "), -1, 0.0,
+			top, width, height, FALSE, &page_start, &pages);
 		pango_font_description_free (font);
 		font = get_font_for_size (12, PANGO_WEIGHT_NORMAL);
-		top = print_attendees (context, font, cr, 0.0, width, top, height, comp, page_nr, &pages);
+		top = print_attendees (
+			context, font, cr, 0.0, width,
+			top, height, comp, page_nr, &pages);
 		top += get_font_size (font) - 6;
 	}
 
@@ -2637,9 +2669,13 @@ print_comp_draw_real (GtkPrintOperation *operation,
 		if (priority && *priority >= 0) {
 			gchar *pri_text;
 
-			pri_text = g_strdup_printf (_("Priority: %s"), e_cal_util_priority_to_string (*priority));
-			top = bound_text (context, font, pri_text, -1,
-					  0.0, top, width, height, FALSE, &page_start, &pages);
+			pri_text = g_strdup_printf (
+				_("Priority: %s"),
+				e_cal_util_priority_to_string (*priority));
+			top = bound_text (
+				context, font, pri_text, -1,
+				0.0, top, width, height, FALSE,
+				&page_start, &pages);
 			top += get_font_size (font) - 6;
 			g_free (pri_text);
 		}
@@ -2713,7 +2749,11 @@ print_comp_draw_real (GtkPrintOperation *operation,
 		for (line = ptext->value; line != NULL; line = next_line) {
 			next_line = strchr (line, '\n');
 
-			top = bound_text (context, font, line, next_line ? next_line - line : -1, 0.0, top + 3, width, height, TRUE, &page_start, &pages);
+			top = bound_text (
+				context, font, line,
+				next_line ? next_line - line : -1,
+				0.0, top + 3, width, height, TRUE,
+				&page_start, &pages);
 
 			if (next_line) {
 				next_line ++;
