@@ -27,7 +27,24 @@
 #include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 
+#include <camel/camel-charset-map.h>
+#include <camel/camel-cipher-context.h>
+#include <camel/camel-folder.h>
+#include <camel/camel-gpg-context.h>
 #include <camel/camel-iconv.h>
+#include <camel/camel-mime-filter-basic.h>
+#include <camel/camel-mime-filter-canon.h>
+#include <camel/camel-mime-filter-charset.h>
+#include <camel/camel-mime-filter-tohtml.h>
+#include <camel/camel-multipart-encrypted.h>
+#include <camel/camel-multipart-signed.h>
+#include <camel/camel-stream-filter.h>
+#include <camel/camel-stream-fs.h>
+#include <camel/camel-stream-mem.h>
+#include <camel/camel-string-utils.h>
+#if defined (HAVE_NSS)
+#include <camel/camel-smime-context.h>
+#endif
 
 #include "e-composer-actions.h"
 #include "e-composer-autosave.h"
@@ -35,6 +52,7 @@
 #include "e-util/e-binding.h"
 #include "e-util/e-charset.h"
 #include "e-util/e-mktemp.h"
+#include "e-util/e-selection.h"
 #include "e-util/e-util.h"
 #include "e-util/gconf-bridge.h"
 #include "widgets/misc/e-attachment-icon-view.h"
@@ -94,6 +112,7 @@ struct _EMsgComposerPrivate {
 	GtkWidget *header_table;
 	GtkWidget *attachment_paned;
 
+	EFocusTracker *focus_tracker;
 	GtkWindowGroup *window_group;
 
 	GtkActionGroup *charset_actions;
@@ -130,7 +149,7 @@ struct _EMsgComposerPrivate {
 	gboolean mail_sent;
 };
 
-void		e_composer_private_init		(EMsgComposer *composer);
+void		e_composer_private_constructed	(EMsgComposer *composer);
 void		e_composer_private_dispose	(EMsgComposer *composer);
 void		e_composer_private_finalize	(EMsgComposer *composer);
 
@@ -139,8 +158,12 @@ void		e_composer_private_finalize	(EMsgComposer *composer);
 void		e_composer_actions_init		(EMsgComposer *composer);
 gchar *		e_composer_find_data_file	(const gchar *basename);
 gchar *		e_composer_get_default_charset	(void);
+gboolean	e_composer_paste_html		(EMsgComposer *composer,
+						 GtkClipboard *clipboard);
 gboolean	e_composer_paste_image		(EMsgComposer *composer,
 						 GtkClipboard *clipboard);
+gboolean	e_composer_paste_text		(EMsgComposer *composer,
+						 GtkClipboard *clipboard);
 gboolean	e_composer_paste_uris		(EMsgComposer *composer,
 						 GtkClipboard *clipboard);
 
