@@ -17,6 +17,9 @@
 
 #include "e-plugin-ui.h"
 
+#include "e-util.h"
+#include "e-ui-manager.h"
+
 #include <string.h>
 
 #define E_PLUGIN_UI_HOOK_GET_PRIVATE(obj) \
@@ -238,8 +241,12 @@ plugin_ui_hook_merge_ui (EPluginUIHook *hook,
 	ui_definition = g_hash_table_lookup (hash_table, id);
 	g_return_val_if_fail (ui_definition != NULL, 0);
 
-	merge_id = gtk_ui_manager_add_ui_from_string (
-		ui_manager, ui_definition, -1, &error);
+	if (E_IS_UI_MANAGER (ui_manager))
+		merge_id = e_ui_manager_add_ui_from_string (
+			E_UI_MANAGER (ui_manager), ui_definition, &error);
+	else
+		merge_id = gtk_ui_manager_add_ui_from_string (
+			ui_manager, ui_definition, -1, &error);
 
 	if (error != NULL) {
 		g_warning ("%s", error->message);
@@ -449,9 +456,7 @@ plugin_ui_hook_construct (EPluginHook *hook,
 
 		/* Extract the XML content below <ui-manager> */
 		buffer = xmlBufferCreate ();
-		for (child = xmlFirstElementChild (node); child != NULL;
-			child = xmlNextElementSibling (child)) {
-
+		for (child = node->children; child != NULL; child = child->next) {
 			xmlNodeDump (buffer, node->doc, child, 2, 1);
 			temp = (const gchar *) xmlBufferContent (buffer);
 			g_string_append (content, temp);
