@@ -117,6 +117,9 @@ emf_finalize (GObject *object)
 	if (emf->session)
 		camel_object_unref (emf->session);
 
+	if (emf->message)
+		camel_object_unref (emf->message);
+
 	g_hash_table_destroy (emf->inline_table);
 
 	em_format_clear_headers(emf);
@@ -1229,6 +1232,7 @@ em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
 	const gchar *charset = NULL;
 	CamelMimeFilterWindows *windows = NULL;
 	CamelStream *mem_stream = NULL;
+	GByteArray *mem_bytes;
 	gsize size;
 	gsize max;
 	GConfClient *gconf;
@@ -1261,7 +1265,8 @@ em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
 		charset = emf->default_charset;
 	}
 
-	mem_stream = (CamelStream *)camel_stream_mem_new ();
+	mem_bytes = g_byte_array_new ();
+	mem_stream = camel_stream_mem_new_with_byte_array (mem_bytes);
 	filter_stream = camel_stream_filter_new_with_stream(mem_stream);
 
 	if ((filter = camel_mime_filter_charset_new_convert(charset, "UTF-8"))) {
@@ -1288,11 +1293,12 @@ em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
 		camel_stream_write_to_stream(mem_stream, (CamelStream *)stream);
 		camel_stream_flush((CamelStream *)stream);
 	} else {
-		((EMFormatClass *)G_OBJECT_GET_CLASS(emf))->format_optional(emf, stream, (CamelMimePart *)dw, mem_stream);
+		((EMFormatClass *)G_OBJECT_GET_CLASS(emf))->format_optional(emf, stream, (CamelMimePart *)dw, mem_bytes);
 	}
 
 	if (windows)
 		camel_object_unref(windows);
+	camel_object_unref (mem_stream);
 }
 
 /**
@@ -1757,7 +1763,7 @@ emf_application_mbox (EMFormat *emf,
 
 	mem_stream = camel_stream_mem_new ();
 	camel_data_wrapper_decode_to_stream (
-		CAMEL_DATA_WRAPPER (mime_part), mem_stream);
+		camel_medium_get_content_object (CAMEL_MEDIUM (mime_part)), mem_stream);
 	camel_seekable_stream_seek (
 		CAMEL_SEEKABLE_STREAM (mem_stream), 0, CAMEL_STREAM_SET);
 	camel_mime_parser_init_with_stream (parser, mem_stream);
@@ -2015,10 +2021,11 @@ em_format_snoop_type (CamelMimePart *part)
 
 	dw = camel_medium_get_content_object((CamelMedium *)part);
 	if (!camel_data_wrapper_is_offline(dw)) {
-		CamelStreamMem *mem = (CamelStreamMem *)camel_stream_mem_new();
+		GByteArray *buffer = g_byte_array_new ();
+		CamelStreamMem *mem = (CamelStreamMem *)camel_stream_mem_new_with_byte_array(buffer);
 
 		if (camel_data_wrapper_decode_to_stream(dw, (CamelStream *)mem) > 0) {
-			gchar *ct = g_content_type_guess (filename, mem->buffer->data, mem->buffer->len, NULL);
+			gchar *ct = g_content_type_guess (filename, buffer->data, buffer->len, NULL);
 
 			if (ct)
 				magic_type = g_content_type_get_mime_type (ct);
