@@ -31,7 +31,7 @@
 
 #include <glib/gi18n.h>
 
-#include "e-util/e-alert.h"
+#include "e-util/e-alert-dialog.h"
 #include "e-util/e-util-private.h"
 #include "e-util/e-util.h"
 
@@ -146,7 +146,7 @@ add_editor_response (GtkWidget *dialog, gint button, ERuleEditor *editor)
 		EAlert *alert = NULL;
 		if (!e_filter_rule_validate (editor->edit, &alert)) {
 			e_alert_run_dialog (GTK_WINDOW (dialog), alert);
-			e_alert_free (alert);
+			g_object_unref (alert);
 			return;
 		}
 
@@ -294,7 +294,7 @@ edit_editor_response (GtkWidget *dialog, gint button, ERuleEditor *editor)
 		EAlert *alert = NULL;
 		if (!e_filter_rule_validate (editor->edit, &alert)) {
 			e_alert_run_dialog (GTK_WINDOW (dialog), alert);
-			e_alert_free (alert);
+			g_object_unref (alert);
 			return;
 		}
 
@@ -352,7 +352,9 @@ rule_edit (GtkWidget *widget, ERuleEditor *editor)
 	gtk_window_set_title ((GtkWindow *) editor->dialog, _("Edit Rule"));
 	gtk_window_set_default_size (GTK_WINDOW (editor->dialog), 650, 400);
 	gtk_window_set_resizable (GTK_WINDOW (editor->dialog), TRUE);
-	gtk_widget_set_parent_window (GTK_WIDGET (editor->dialog), GTK_WIDGET (editor)->window);
+	gtk_widget_set_parent_window (
+		GTK_WIDGET (editor->dialog),
+		gtk_widget_get_window (GTK_WIDGET (editor)));
 	gtk_container_set_border_width ((GtkContainer *) editor->dialog, 6);
 
 	content_area = gtk_dialog_get_content_area (GTK_DIALOG (editor->dialog));
@@ -511,7 +513,7 @@ static void
 rule_bottom (GtkWidget *widget, ERuleEditor *editor)
 {
 	gint pos;
-	gint index = -1, count = 0;
+	gint count = 0;
 	EFilterRule *rule = NULL;
 
 	update_selected_rule(editor);
@@ -519,11 +521,8 @@ rule_bottom (GtkWidget *widget, ERuleEditor *editor)
 	pos = e_rule_context_get_rank_rule (
 		editor->context, editor->current, editor->source);
 	/* There's probably a better/faster way to get the count of the list here */
-	while ((rule = e_rule_context_next_rule (editor->context, rule, editor->source))) {
-		if (rule == editor->current)
-			index = count;
+	while ((rule = e_rule_context_next_rule (editor->context, rule, editor->source)))
 		count++;
-	}
 	count--;
 	if (pos >= 0)
 		rule_move (editor, pos, count);
@@ -775,14 +774,12 @@ rule_able_toggled (GtkCellRendererToggle *renderer,
                    gpointer user_data)
 {
 	GtkWidget *table = user_data;
-	GtkTreeSelection *selection;
 	GtkTreeModel *model;
 	GtkTreePath *path;
 	GtkTreeIter iter;
 
 	path = gtk_tree_path_new_from_string (path_string);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (table));
 
 	if (gtk_tree_model_get_iter (model, &iter, path)) {
 		EFilterRule *rule = NULL;
