@@ -280,11 +280,10 @@ close_on_idle_cb (gpointer browser)
 }
 
 static void
-mail_browser_message_list_built_cb (EMailBrowser *browser, MessageList *message_list)
+mail_browser_message_list_built_cb (EMailBrowser *browser,
+                                    MessageList *message_list)
 {
-	g_return_if_fail (browser != NULL);
 	g_return_if_fail (E_IS_MAIL_BROWSER (browser));
-	g_return_if_fail (message_list != NULL);
 	g_return_if_fail (IS_MESSAGE_LIST (message_list));
 
 	if (!message_list_count (message_list))
@@ -446,7 +445,8 @@ mail_browser_dispose (GObject *object)
 	}
 
 	if (priv->message_list != NULL) {
-		g_object_unref (priv->message_list);
+		/* This will cancel a regen operation. */
+		gtk_widget_destroy (priv->message_list);
 		priv->message_list = NULL;
 	}
 
@@ -619,6 +619,8 @@ mail_browser_constructed (GObject *object)
 	id = "org.gnome.evolution.mail.browser";
 	e_plugin_ui_register_manager (ui_manager, id, object);
 	e_plugin_ui_enable_manager (ui_manager, id);
+
+	e_mail_reader_connect_headers (E_MAIL_READER (reader));
 }
 
 static gboolean
