@@ -560,7 +560,7 @@ struct _save_draft_info {
 };
 
 static void
-composer_set_no_change (EMsgComposer *composer, gboolean drop_undo, gboolean editor_changed)
+composer_set_no_change (EMsgComposer *composer)
 {
 	GtkhtmlEditor *editor;
 
@@ -568,11 +568,8 @@ composer_set_no_change (EMsgComposer *composer, gboolean drop_undo, gboolean edi
 
 	editor = GTKHTML_EDITOR (composer);
 
-	if (drop_undo)
-		gtkhtml_editor_drop_undo (editor);
-
-	if (editor_changed)
-		gtkhtml_editor_set_changed (editor, FALSE);
+	gtkhtml_editor_drop_undo (editor);
+	gtkhtml_editor_set_changed (editor, FALSE);
 }
 
 static void
@@ -585,8 +582,6 @@ save_draft_done (CamelFolder *folder, CamelMimeMessage *msg, CamelMessageInfo *i
 	if (!ok)
 		goto done;
 
-	composer_set_no_change (sdi->composer, FALSE, FALSE);
-
 	if ((emcs = sdi->emcs) == NULL)
 		emcs = emcs_new ();
 
@@ -763,7 +758,7 @@ em_utils_compose_new_message (const gchar *fromuri)
 	if (composer == NULL)
 		return;
 
-	composer_set_no_change (E_MSG_COMPOSER (composer), TRUE, TRUE);
+	composer_set_no_change (E_MSG_COMPOSER (composer));
 
 	gtk_widget_show (composer);
 }
@@ -783,7 +778,7 @@ em_utils_compose_lite_new_message (const gchar *fromuri)
 	if (composer == NULL)
 		return NULL;
 
-	composer_set_no_change (E_MSG_COMPOSER (composer), TRUE, TRUE);
+	composer_set_no_change (E_MSG_COMPOSER (composer));
 
 	return E_MSG_COMPOSER (composer);
 }
@@ -814,7 +809,7 @@ em_utils_compose_new_message_with_mailto (const gchar *url, const gchar *fromuri
 	    && (account = mail_config_get_account_by_source_url(fromuri)))
 		e_composer_header_table_set_account_name (table, account->name);
 
-	composer_set_no_change (composer, TRUE, url == NULL);
+	composer_set_no_change (composer);
 
 	if (!e_msg_composer_get_lite ()) {
 		gtk_widget_show ((GtkWidget *) composer);
@@ -930,6 +925,7 @@ traverse_parts (GSList *clues, CamelMimeMessage *message, CamelDataWrapper *cont
 		CamelMimePart *part = CAMEL_MIME_PART (content);
 		CamelContentType *type;
 		CamelStream *mem;
+		GByteArray *mem_bytes;
 		gchar *str;
 
 		content = camel_medium_get_content_object (CAMEL_MEDIUM (part));
@@ -945,10 +941,11 @@ traverse_parts (GSList *clues, CamelMimeMessage *message, CamelDataWrapper *cont
 		if (!camel_content_type_is (type, "text", "*"))
 			return;
 
-		mem = camel_stream_mem_new ();
+		mem_bytes = g_byte_array_new ();
+		mem = camel_stream_mem_new_with_byte_array (mem_bytes);
 		camel_data_wrapper_decode_to_stream (content, mem);
 
-		str = g_strndup ((const gchar *)((CamelStreamMem *) mem)->buffer->data, ((CamelStreamMem *) mem)->buffer->len);
+		str = g_strndup ((const gchar *)mem_bytes->data, mem_bytes->len);
 		camel_object_unref (mem);
 
 		if (replace_variables (clues, message, &str)) {
@@ -994,7 +991,7 @@ edit_message (CamelMimeMessage *message, CamelFolder *drafts, const gchar *uid)
 		emcs_set_drafts_info (emcs, drafts, uid);
 	}
 
-	composer_set_no_change (composer, TRUE, FALSE);
+	composer_set_no_change (composer);
 
 	if (!e_msg_composer_get_lite())
 		gtk_widget_show (GTK_WIDGET (composer));
@@ -1155,7 +1152,7 @@ forward_attached (CamelFolder *folder, GPtrArray *uids, GPtrArray *messages, Cam
 	if (uids)
 		setup_forward_attached_callbacks (composer, folder, uids);
 
-	composer_set_no_change (composer, TRUE, TRUE);
+	composer_set_no_change (composer);
 
 	if (!e_msg_composer_get_lite())
 		gtk_widget_show (GTK_WIDGET (composer));
@@ -1244,7 +1241,7 @@ forward_non_attached (CamelFolder *folder, GPtrArray *uids, GPtrArray *messages,
 				}
 
 				emu_update_composers_security (composer, validity_found);
-				composer_set_no_change (composer, TRUE, TRUE);
+				composer_set_no_change (composer);
 				if (!e_msg_composer_get_lite())
 					gtk_widget_show (GTK_WIDGET (composer));
 			}
@@ -1423,7 +1420,7 @@ em_utils_redirect_message (CamelMimeMessage *message)
 
 	gtk_widget_show (GTK_WIDGET (composer));
 
-	composer_set_no_change (composer, TRUE, TRUE);
+	composer_set_no_change (composer);
 }
 
 static void
@@ -2197,9 +2194,12 @@ reply_to_message(CamelFolder *folder, const gchar *uid, CamelMimeMessage *messag
 {
 	struct _reply_data *rd = user_data;
 
-	if (message != NULL)
+	if (message != NULL) {
+		/* get_message_free() will also unref the message, so we need
+		   an extra ref for em_utils_reply_to_message() to drop. */
+		camel_object_ref(message);
 		em_utils_reply_to_message(folder, uid, message, rd->mode, rd->source);
-
+	}
 	if (rd->source)
 		g_object_unref(rd->source);
 	g_free(rd);
@@ -2220,7 +2220,7 @@ reply_to_message(CamelFolder *folder, const gchar *uid, CamelMimeMessage *messag
  *
  * If @message is non null, then it is used directly, @folder and @uid
  * may be supplied in order to update the message flags once it has
- * been replied to.
+ * been replied to. Note that @message will be unreferenced on completion.
  **/
 EMsgComposer *
 em_utils_reply_to_message(CamelFolder *folder, const gchar *uid, CamelMimeMessage *message, gint mode, EMFormat *source)
@@ -2283,10 +2283,11 @@ em_utils_reply_to_message(CamelFolder *folder, const gchar *uid, CamelMimeMessag
 
 	composer_set_body (composer, message, source);
 
+	camel_object_unref(message);
 	emcs = g_object_get_data (G_OBJECT (composer), "emcs");
 	emcs_set_folder_info (emcs, folder, uid, flags, flags);
 
-	composer_set_no_change (composer, TRUE, TRUE);
+	composer_set_no_change (composer);
 
 	if (!e_msg_composer_get_lite())
 		gtk_widget_show (GTK_WIDGET (composer));
