@@ -54,6 +54,8 @@
 #include "e-util/e-alert-dialog.h"
 #include "e-util/e-util.h"
 
+#include "misc/e-selectable.h"
+
 #include "em-vfolder-rule.h"
 
 #include "mail-mt.h"
@@ -110,6 +112,8 @@ struct _EMFolderTreePrivate {
 
 	GtkCellRenderer *text_renderer;
 
+	GtkWidget *selectable; /* an ESelectable, where to pass selectable calls */
+
 	/* Signal handler IDs */
 	gulong selection_changed_handler_id;
 };
@@ -207,7 +211,7 @@ folder_tree_get_folder_info__done (struct _EMFolderTreeGetFolderInfo *m)
 	GtkTreeView *tree_view;
 	GtkTreeModel *model;
 	GtkTreePath *path;
-	gboolean is_store;
+	gboolean is_store, need_add_node;
 
 	/* check that we haven't been destroyed */
 	g_return_if_fail (GTK_IS_TREE_VIEW (m->folder_tree));
@@ -247,6 +251,8 @@ folder_tree_get_folder_info__done (struct _EMFolderTreeGetFolderInfo *m)
 	/* get the first child (which will be a dummy node) */
 	gtk_tree_model_iter_children (model, &iter, &root);
 
+	need_add_node = TRUE;
+
 	/* Traverse to the last valid iter, or the "Loading..." node */
 	do {
 		gboolean is_store_node = FALSE, is_folder_node = FALSE;
@@ -256,8 +262,11 @@ folder_tree_get_folder_info__done (struct _EMFolderTreeGetFolderInfo *m)
 		gtk_tree_model_get (model, &iter, COL_BOOL_IS_STORE, &is_store_node, COL_BOOL_IS_FOLDER, &is_folder_node, -1);
 
 		/* stop on a "Loading..." node */
-		if (!is_store_node && !is_folder_node)
+		if (!is_store_node && !is_folder_node) {
+			/* remember it found a "Loading..." node and overwrite or remove it later */
+			need_add_node = FALSE;
 			break;
+		}
 
 	} while (gtk_tree_model_iter_next (model, &iter));
 
@@ -274,7 +283,8 @@ folder_tree_get_folder_info__done (struct _EMFolderTreeGetFolderInfo *m)
 
 	if (fi == NULL) {
 		/* no children afterall... remove the "Loading..." placeholder node */
-		gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
+		if (!need_add_node)
+			gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
 
 		if (is_store) {
 			path = gtk_tree_model_get_path (model, &root);
@@ -286,16 +296,22 @@ folder_tree_get_folder_info__done (struct _EMFolderTreeGetFolderInfo *m)
 		gint fully_loaded = (m->flags & CAMEL_STORE_FOLDER_INFO_RECURSIVE) ? TRUE : FALSE;
 
 		do {
-			gboolean known = g_hash_table_lookup (si->full_hash, fi->full_name) != NULL;
+			if (g_hash_table_lookup (si->full_hash, fi->full_name) == NULL) {
+				if (need_add_node)
+					gtk_tree_store_append (GTK_TREE_STORE (model), &iter, &root);
+				need_add_node = TRUE;
 
-			if (!known)
 				em_folder_tree_model_set_folder_info (
 					EM_FOLDER_TREE_MODEL (model),
 					&iter, si, fi, fully_loaded);
+			}
 
-			if ((fi = fi->next) != NULL && !known)
-				gtk_tree_store_append (GTK_TREE_STORE (model), &iter, &root);
+			fi = fi->next;
 		} while (fi != NULL);
+
+		/* all children are known, remove the "Loading..." node */
+		if (!need_add_node)
+			gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
 	}
 
 	gtk_tree_store_set (
@@ -578,7 +594,7 @@ folder_tree_cell_edited_cb (EMFolderTree *folder_tree,
 		COL_STRING_DISPLAY_NAME, &old_name,
 		COL_STRING_FULL_NAME, &old_full_name, -1);
 
-	if (g_strcmp0 (new_name, old_name) == 0)
+	if (!old_name || !old_full_name || g_strcmp0 (new_name, old_name) == 0)
 		goto exit;
 
 	/* Check for invalid characters. */
@@ -1087,12 +1103,15 @@ render_icon (GtkTreeViewColumn *column,
              GtkTreeIter *iter)
 {
 	GtkTreeSelection *selection;
+	GtkTreePath *drag_dest_row;
 	GtkWidget *tree_view;
 	GIcon *icon;
 	guint unread;
 	guint old_unread;
 	gchar *icon_name;
-	gboolean row_selected, is_drafts = FALSE;
+	gboolean is_selected;
+	gboolean is_drafts = FALSE;
+	gboolean is_drag_dest = FALSE;
 
 	gtk_tree_model_get (
 		model, iter,
@@ -1105,14 +1124,37 @@ render_icon (GtkTreeViewColumn *column,
 	if (icon_name == NULL)
 		return;
 
-	icon = g_themed_icon_new (icon_name);
-
 	tree_view = gtk_tree_view_column_get_tree_view (column);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
-	row_selected = gtk_tree_selection_iter_is_selected (selection, iter);
+	is_selected = gtk_tree_selection_iter_is_selected (selection, iter);
+
+	gtk_tree_view_get_drag_dest_row (
+		GTK_TREE_VIEW (tree_view), &drag_dest_row, NULL);
+	if (drag_dest_row != NULL) {
+		GtkTreePath *path;
+
+		path = gtk_tree_model_get_path (model, iter);
+		if (gtk_tree_path_compare (path, drag_dest_row) == 0)
+			is_drag_dest = TRUE;
+		gtk_tree_path_free (path);
+
+		gtk_tree_path_free (drag_dest_row);
+	}
+
+	if (g_strcmp0 (icon_name, "folder") == 0) {
+		if (is_selected) {
+			g_free (icon_name);
+			icon_name = g_strdup ("folder-open");
+		} else if (is_drag_dest) {
+			g_free (icon_name);
+			icon_name = g_strdup ("folder-drag-accept");
+		}
+	}
+
+	icon = g_themed_icon_new (icon_name);
 
 	/* Show an emblem if there's new mail. */
-	if (!row_selected && unread > old_unread && !is_drafts) {
+	if (!is_selected && unread > old_unread && !is_drafts) {
 		GIcon *temp_icon;
 		GEmblem *emblem;
 
@@ -1148,6 +1190,8 @@ folder_tree_new (EMFolderTree *folder_tree)
 	tree = GTK_WIDGET (folder_tree);
 	GTK_WIDGET_SET_FLAGS(tree, GTK_CAN_FOCUS);
 
+	folder_tree->priv->selectable = NULL;
+
 	column = gtk_tree_view_column_new ();
 	gtk_tree_view_append_column ((GtkTreeView *) tree, column);
 
@@ -1280,6 +1324,80 @@ folder_tree_init (EMFolderTree *folder_tree)
 	em_folder_tree_construct (folder_tree);
 }
 
+/* Sets a selectable widget, which will be used for update-actions and select-all
+   selectable interface functions. This can be NULL, then nothing can be selected
+   and calling selectable function does nothing. */
+void
+em_folder_tree_set_selectable_widget (EMFolderTree *folder_tree, GtkWidget *selectable)
+{
+	if (selectable)
+		g_return_if_fail (E_IS_SELECTABLE (selectable));
+
+	folder_tree->priv->selectable = selectable;
+}
+
+static void
+folder_tree_selectable_update_actions (ESelectable *selectable,
+                                        EFocusTracker *focus_tracker,
+                                        GdkAtom *clipboard_targets,
+                                        gint n_clipboard_targets)
+{
+	EMFolderTree *folder_tree;
+
+	folder_tree = EM_FOLDER_TREE (selectable);
+	g_return_if_fail (folder_tree != NULL);
+
+	if (folder_tree->priv->selectable) {
+		ESelectableInterface *iface = E_SELECTABLE_GET_INTERFACE (folder_tree->priv->selectable);
+
+		g_return_if_fail (iface != NULL);
+		g_return_if_fail (iface->update_actions != NULL);
+
+		iface->update_actions (E_SELECTABLE (folder_tree->priv->selectable), focus_tracker, clipboard_targets, n_clipboard_targets);
+	}
+}
+
+#define folder_tree_selectable_func(_func)									\
+static void													\
+folder_tree_selectable_ ## _func (ESelectable *selectable)							\
+{														\
+	EMFolderTree *folder_tree;										\
+														\
+	folder_tree = EM_FOLDER_TREE (selectable);								\
+	g_return_if_fail (folder_tree != NULL);									\
+														\
+	if (folder_tree->priv->selectable) {									\
+		ESelectableInterface *iface = E_SELECTABLE_GET_INTERFACE (folder_tree->priv->selectable);	\
+														\
+		g_return_if_fail (iface != NULL);								\
+		if (iface-> _func ) {										\
+			if (gtk_widget_get_can_focus (folder_tree->priv->selectable) &&				\
+			    !gtk_widget_has_focus (folder_tree->priv->selectable))				\
+				gtk_widget_grab_focus (folder_tree->priv->selectable);				\
+			iface-> _func (E_SELECTABLE (folder_tree->priv->selectable));				\
+		}												\
+	}													\
+}
+
+folder_tree_selectable_func (cut_clipboard);
+folder_tree_selectable_func (copy_clipboard);
+folder_tree_selectable_func (paste_clipboard);
+folder_tree_selectable_func (delete_selection);
+folder_tree_selectable_func (select_all);
+
+#undef folder_tree_selectable_func
+
+static void
+folder_tree_selectable_init (ESelectableInterface *interface)
+{
+	interface->update_actions = folder_tree_selectable_update_actions;
+	interface->cut_clipboard = folder_tree_selectable_cut_clipboard;
+	interface->copy_clipboard = folder_tree_selectable_copy_clipboard;
+	interface->paste_clipboard = folder_tree_selectable_paste_clipboard;
+	interface->delete_selection = folder_tree_selectable_delete_selection;
+	interface->select_all = folder_tree_selectable_select_all;
+}
+
 GType
 em_folder_tree_get_type (void)
 {
@@ -1299,8 +1417,17 @@ em_folder_tree_get_type (void)
 			NULL   /* value_table */
 		};
 
+		static const GInterfaceInfo selectable_info = {
+			(GInterfaceInitFunc) folder_tree_selectable_init,
+			(GInterfaceFinalizeFunc) NULL,
+			NULL   /* interface_data */
+		};
+
 		type = g_type_register_static (
 			GTK_TYPE_TREE_VIEW, "EMFolderTree", &type_info, 0);
+
+		g_type_add_interface_static (
+			type, E_TYPE_SELECTABLE, &selectable_info);
 	}
 
 	return type;
@@ -1317,19 +1444,26 @@ tree_drag_begin (GtkWidget *widget, GdkDragContext *context, EMFolderTree *folde
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 	GtkTreeSelection *selection;
+	GtkTreeView *tree_view;
+	GdkColormap *colormap;
+	GdkPixmap *pixmap;
 	GtkTreeModel *model;
 	GtkTreePath *path;
 	GtkTreeIter iter;
 
-	selection = gtk_tree_view_get_selection ((GtkTreeView *) widget);
+	tree_view = GTK_TREE_VIEW (widget);
+	selection = gtk_tree_view_get_selection (tree_view);
 	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
 		return;
 
 	path = gtk_tree_model_get_path (model, &iter);
 	priv->drag_row = gtk_tree_row_reference_new (model, path);
-	gtk_tree_path_free (path);
 
-	/* FIXME: set a drag icon? */
+	pixmap = gtk_tree_view_create_row_drag_icon (tree_view, path);
+	colormap = gdk_drawable_get_colormap (pixmap);
+	gtk_drag_set_icon_pixmap (context, colormap, pixmap, NULL, 0, 0);
+
+	gtk_tree_path_free (path);
 }
 
 static void
@@ -1529,9 +1663,7 @@ folder_tree_drop_async__free (struct _DragDataReceivedAsync *m)
 	g_object_unref(m->context);
 	camel_object_unref(m->store);
 	g_free(m->full_name);
-
-	g_free(m->selection->data);
-	g_free(m->selection);
+	gtk_selection_data_free (m->selection);
 }
 
 static MailMsgInfo folder_tree_drop_async_info = {
@@ -1601,10 +1733,7 @@ tree_drag_data_received(GtkWidget *widget, GdkDragContext *context, gint x, gint
 	m->info = info;
 
 	/* need to copy, goes away once we exit */
-	m->selection = g_malloc0(sizeof(*m->selection));
-	m->selection->data = g_malloc(selection->length);
-	memcpy(m->selection->data, selection->data, selection->length);
-	m->selection->length = selection->length;
+	m->selection = gtk_selection_data_copy (selection);
 
 	tree_drag_data_action(m);
 }
@@ -1616,7 +1745,11 @@ is_special_local_folder (const gchar *name)
 }
 
 static GdkAtom
-folder_tree_drop_target(EMFolderTree *folder_tree, GdkDragContext *context, GtkTreePath *path)
+folder_tree_drop_target (EMFolderTree *folder_tree,
+                         GdkDragContext *context,
+                         GtkTreePath *path,
+                         GdkDragAction *actions,
+                         GdkDragAction *suggested_action)
 {
 	EMFolderTreePrivate *p = folder_tree->priv;
 	gchar *full_name = NULL, *uri = NULL, *src_uri = NULL;
@@ -1635,6 +1768,10 @@ folder_tree_drop_target(EMFolderTree *folder_tree, GdkDragContext *context, GtkT
 	if (!gtk_tree_model_get_iter (model, &iter, path))
 		return GDK_NONE;
 
+	/* We may override these further down. */
+	*actions = context->actions;
+	*suggested_action = context->suggested_action;
+
 	gtk_tree_model_get (
 		model, &iter,
 		COL_BOOL_IS_STORE, &is_store,
@@ -1685,11 +1822,14 @@ folder_tree_drop_target(EMFolderTree *folder_tree, GdkDragContext *context, GtkT
 		GtkTreePath *src_path = gtk_tree_row_reference_get_path(p->drag_row);
 
 		if (src_path) {
+			guint32 src_flags = 0;
+
 			if (gtk_tree_model_get_iter (model, &iter, src_path))
 				gtk_tree_model_get (
 					model, &iter,
 					COL_POINTER_CAMEL_STORE, &sstore,
-					COL_STRING_URI, &src_uri, -1);
+					COL_STRING_URI, &src_uri,
+					COL_UINT_FLAGS, &src_flags, -1);
 
 			/* can't dnd onto itself or below itself - bad things happen,
 			   no point dragging to where we were either */
@@ -1702,6 +1842,26 @@ folder_tree_drop_target(EMFolderTree *folder_tree, GdkDragContext *context, GtkT
 			}
 
 			gtk_tree_path_free(src_path);
+
+			if ((src_flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_INBOX || (src_flags & CAMEL_FOLDER_SYSTEM) != 0) {
+				/* allow only copy of the Inbox and other system folders */
+				GdkAtom xfolder;
+
+				/* force copy for special local folders */
+				*suggested_action = GDK_ACTION_COPY;
+				*actions = GDK_ACTION_COPY;
+				xfolder = drop_atoms[DND_DROP_TYPE_FOLDER];
+				while (targets != NULL) {
+					if (targets->data == (gpointer) xfolder) {
+						atom = xfolder;
+						goto done;
+					}
+
+					targets = targets->next;
+				}
+
+				goto done;
+			}
 		}
 	}
 
@@ -1721,8 +1881,9 @@ folder_tree_drop_target(EMFolderTree *folder_tree, GdkDragContext *context, GtkT
 
 				camel_url_free (url);
 
-				/* TODO: not sure if this is legal, but it works, force copy for special local folders */
-				context->suggested_action = GDK_ACTION_COPY;
+				/* force copy for special local folders */
+				*suggested_action = GDK_ACTION_COPY;
+				*actions = GDK_ACTION_COPY;
 				xfolder = drop_atoms[DND_DROP_TYPE_FOLDER];
 				while (targets != NULL) {
 					if (targets->data == (gpointer) xfolder) {
@@ -1824,6 +1985,8 @@ tree_drag_drop (GtkWidget *widget, GdkDragContext *context, gint x, gint y, guin
 	GtkTreeViewColumn *column;
 	GtkTreeView *tree_view;
 	gint cell_x, cell_y;
+	GdkDragAction actions;
+	GdkDragAction suggested_action;
 	GtkTreePath *path;
 	GdkAtom target;
 
@@ -1845,12 +2008,13 @@ tree_drag_drop (GtkWidget *widget, GdkDragContext *context, gint x, gint y, guin
 	if (!gtk_tree_view_get_path_at_pos (tree_view, x, y, &path, &column, &cell_x, &cell_y))
 		return FALSE;
 
-	target = folder_tree_drop_target(folder_tree, context, path);
-	gtk_tree_path_free (path);
-	if (target == GDK_NONE)
-		return FALSE;
+	target = folder_tree_drop_target (
+		folder_tree, context, path,
+		&actions, &suggested_action);
 
-	return TRUE;
+	gtk_tree_path_free (path);
+
+	return (target != GDK_NONE);
 }
 
 static void
@@ -1858,7 +2022,7 @@ tree_drag_end (GtkWidget *widget, GdkDragContext *context, EMFolderTree *folder_
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 
-	if (priv->drag_row) {
+	if (priv->drag_row != NULL) {
 		gtk_tree_row_reference_free (priv->drag_row);
 		priv->drag_row = NULL;
 	}
@@ -1887,7 +2051,8 @@ tree_drag_leave (GtkWidget *widget, GdkDragContext *context, guint time, EMFolde
 		priv->autoexpand_id = 0;
 	}
 
-	gtk_tree_view_set_drag_dest_row(tree_view, NULL, GTK_TREE_VIEW_DROP_BEFORE);
+	gtk_tree_view_set_drag_dest_row (
+		tree_view, NULL, GTK_TREE_VIEW_DROP_BEFORE);
 }
 
 #define SCROLL_EDGE_SIZE 15
@@ -1944,13 +2109,20 @@ tree_autoexpand (EMFolderTree *folder_tree)
 }
 
 static gboolean
-tree_drag_motion (GtkWidget *widget, GdkDragContext *context, gint x, gint y, guint time, EMFolderTree *folder_tree)
+tree_drag_motion (GtkWidget *widget,
+                  GdkDragContext *context,
+                  gint x,
+                  gint y,
+                  guint time,
+                  EMFolderTree *folder_tree)
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 	GtkTreeViewDropPosition pos;
 	GtkTreeView *tree_view;
 	GtkTreeModel *model;
-	GdkDragAction action = 0;
+	GdkDragAction actions;
+	GdkDragAction suggested_action;
+	GdkDragAction chosen_action = 0;
 	GtkTreePath *path;
 	GtkTreeIter iter;
 	GdkAtom target;
@@ -1959,11 +2131,12 @@ tree_drag_motion (GtkWidget *widget, GdkDragContext *context, gint x, gint y, gu
 	tree_view = GTK_TREE_VIEW (folder_tree);
 	model = gtk_tree_view_get_model (tree_view);
 
-	if (!gtk_tree_view_get_dest_row_at_pos(tree_view, x, y, &path, &pos))
+	if (!gtk_tree_view_get_dest_row_at_pos (tree_view, x, y, &path, &pos))
 		return FALSE;
 
 	if (priv->autoscroll_id == 0)
-		priv->autoscroll_id = g_timeout_add (150, (GSourceFunc) tree_autoscroll, folder_tree);
+		priv->autoscroll_id = g_timeout_add (
+			150, (GSourceFunc) tree_autoscroll, folder_tree);
 
 	gtk_tree_model_get_iter (model, &iter, path);
 
@@ -1993,33 +2166,36 @@ tree_drag_motion (GtkWidget *widget, GdkDragContext *context, gint x, gint y, gu
 		priv->autoexpand_id = 0;
 	}
 
-	target = folder_tree_drop_target(folder_tree, context, path);
-	if (target != GDK_NONE) {
-		for (i=0; i<NUM_DROP_TYPES; i++) {
-			if (drop_atoms[i] == target) {
-				switch (i) {
-				case DND_DROP_TYPE_UID_LIST:
-				case DND_DROP_TYPE_FOLDER:
-					action = context->suggested_action;
-					if (action == GDK_ACTION_COPY && (context->actions & GDK_ACTION_MOVE))
-						action = GDK_ACTION_MOVE;
-					gtk_tree_view_set_drag_dest_row(tree_view, path, GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
-					break;
-				default:
-					gtk_tree_view_set_drag_dest_row(tree_view, path, GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
-					action = context->suggested_action;
-					break;
-				}
+	target = folder_tree_drop_target (
+		folder_tree, context, path,
+		&actions, &suggested_action);
+	for (i = 0; target != GDK_NONE && i < NUM_DROP_TYPES; i++) {
+		if (drop_atoms[i] != target)
+			continue;
+		switch (i) {
+			case DND_DROP_TYPE_UID_LIST:
+			case DND_DROP_TYPE_FOLDER:
+				chosen_action = suggested_action;
+				if (chosen_action == GDK_ACTION_COPY && (actions & GDK_ACTION_MOVE))
+					chosen_action = GDK_ACTION_MOVE;
+				gtk_tree_view_set_drag_dest_row (
+					tree_view, path,
+					GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
+				break;
+			default:
+				gtk_tree_view_set_drag_dest_row (
+					tree_view, path,
+					GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
+				chosen_action = suggested_action;
 				break;
-			}
 		}
+
+		break;
 	}
 
-	gtk_tree_path_free(path);
+	gdk_drag_status(context, chosen_action, time);
 
-	gdk_drag_status(context, action, time);
-
-	return action != 0;
+	return chosen_action != 0;
 }
 
 void
@@ -2607,8 +2783,10 @@ sort_by_store_and_uri (gconstpointer name1, gconstpointer name2)
 
 /* restores state of a tree (collapsed/expanded) as stores in the given key_file */
 void
-em_folder_tree_restore_state (EMFolderTree *folder_tree, GKeyFile *key_file)
+em_folder_tree_restore_state (EMFolderTree *folder_tree,
+                              GKeyFile *key_file)
 {
+	EShell *shell;
 	GtkTreeModel *tree_model;
 	GtkTreeView *tree_view;
 	GtkTreeIter iter;
@@ -2621,6 +2799,9 @@ em_folder_tree_restore_state (EMFolderTree *folder_tree, GKeyFile *key_file)
 	if (key_file == NULL)
 		return;
 
+	/* XXX Pass this in. */
+	shell = e_shell_get_default ();
+
 	tree_view = GTK_TREE_VIEW (folder_tree);
 	tree_model = gtk_tree_view_get_model (tree_view);
 
@@ -2705,7 +2886,22 @@ em_folder_tree_restore_state (EMFolderTree *folder_tree, GKeyFile *key_file)
 
 		group_name = g_strdup_printf ("Store %s", uri);
 
-		if (!g_key_file_has_key (key_file, group_name, key, NULL)) {
+		if (e_shell_get_express_mode (shell)) {
+			gboolean system = FALSE;
+
+			if (strncmp (uri, "vfolder", 7) == 0 ||
+					strncmp(uri, "mbox", 4) == 0)
+				system = TRUE;
+
+			if (!system && !g_key_file_has_key (key_file, group_name, key, NULL)) {
+				GtkTreePath *path;
+
+				path = gtk_tree_model_get_path (tree_model, &iter);
+				gtk_tree_view_expand_row (tree_view, path, FALSE);
+				gtk_tree_path_free (path);
+			}
+
+		} else if (!g_key_file_has_key (key_file, group_name, key, NULL)) {
 			GtkTreePath *path;
 
 			path = gtk_tree_model_get_path (tree_model, &iter);
