@@ -24,7 +24,7 @@
 #ifndef EM_FOLDER_UTILS_H
 #define EM_FOLDER_UTILS_H
 
-#include <glib.h>
+#include <gtk/gtk.h>
 #include <camel/camel-folder.h>
 #include <camel/camel-store.h>
 #include <mail/em-folder-tree.h>
@@ -40,15 +40,15 @@ gint		em_folder_utils_copy_folders	(CamelStore *fromstore,
 /* FIXME These API's are really busted.  There is no consistency and
  *       most rely on the wrong data. */
 
-void		em_folder_utils_copy_folder	(CamelFolderInfo *folderinfo,
-						 gint delete);
-
+void		em_folder_utils_copy_folder	(GtkWindow *parent,
+						 CamelFolderInfo *folderinfo,
+						 gboolean delete);
 void		em_folder_utils_delete_folder	(CamelFolder *folder);
-void		em_folder_utils_rename_folder	(CamelFolder *folder);
-
 void		em_folder_utils_create_folder	(CamelFolderInfo *folderinfo,
-						 EMFolderTree * emft,
+						 EMFolderTree *emft,
 						 GtkWindow *parent);
+void		em_folder_utils_unsubscribe_folder
+						(const gchar *folder_uri);
 
 const gchar *	em_folder_utils_get_icon_name	(guint32 flags);
 
