@@ -41,8 +41,6 @@
 #include <gtkhtml/gtkhtml.h>
 #include <gtkhtml/gtkhtml-embedded.h>
 
-#include <glade/glade.h>
-
 #include <glib/gi18n.h>
 
 #include <camel/camel-stream.h>
@@ -153,8 +151,8 @@ struct _attach_puri {
 	GtkImage *image;
 	GtkWidget *event_box;
 
-	/* Optional Text Mem Stream */
-	CamelStreamMem *mstream;
+	/* Optional Text Data */
+	GByteArray *mem_bytes;
 
 	/* Signed / Encrypted */
         camel_cipher_validity_sign_t sign;
@@ -195,7 +193,7 @@ efhd_xpkcs7mime_viewcert_clicked (GtkWidget *button,
 	ECert *ec = NULL;
 
 	if (info->cert_data)
-		ec = e_cert_new (info->cert_data);
+		ec = e_cert_new (CERT_DupCertificate (info->cert_data));
 
 	if (ec != NULL) {
 		GtkWidget *w = certificate_viewer_show(ec);
@@ -253,7 +251,7 @@ efhd_xpkcs7mime_add_cert_table (GtkWidget *vbox,
 			g_signal_connect(w, "clicked", G_CALLBACK(efhd_xpkcs7mime_viewcert_clicked), po);
 
 			if (info->cert_data)
-				ec = e_cert_new (info->cert_data);
+				ec = e_cert_new (CERT_DupCertificate (info->cert_data));
 
 			if (ec == NULL)
 				gtk_widget_set_sensitive(w, FALSE);
@@ -277,22 +275,19 @@ efhd_xpkcs7mime_validity_clicked (GtkWidget *button,
                                   EMFormatHTMLPObject *pobject)
 {
 	struct _smime_pobject *po = (struct _smime_pobject *)pobject;
-	GladeXML *xml;
+	GtkBuilder *builder;
 	GtkWidget *vbox, *w;
-	gchar *gladefile;
 
 	if (po->widget)
 		/* FIXME: window raise? */
 		return;
 
-	gladefile = g_build_filename (
-		EVOLUTION_GLADEDIR, "mail-dialogs.glade", NULL);
-	xml = glade_xml_new (gladefile, "message_security_dialog", NULL);
-	g_free (gladefile);
+	builder = gtk_builder_new ();
+	e_load_ui_builder_definition (builder, "mail-dialogs.ui");
 
-	po->widget = glade_xml_get_widget(xml, "message_security_dialog");
+	po->widget = e_builder_get_widget(builder, "message_security_dialog");
 
-	vbox = glade_xml_get_widget(xml, "signature_vbox");
+	vbox = e_builder_get_widget(builder, "signature_vbox");
 	w = gtk_label_new (_(smime_sign_table[po->valid->sign.status].description));
 	gtk_misc_set_alignment((GtkMisc *)w, 0.0, 0.5);
 	gtk_label_set_line_wrap((GtkLabel *)w, TRUE);
@@ -324,7 +319,7 @@ efhd_xpkcs7mime_validity_clicked (GtkWidget *button,
 
 	gtk_widget_show_all(vbox);
 
-	vbox = glade_xml_get_widget(xml, "encryption_vbox");
+	vbox = e_builder_get_widget(builder, "encryption_vbox");
 	w = gtk_label_new(_(smime_encrypt_table[po->valid->encrypt.status].description));
 	gtk_misc_set_alignment((GtkMisc *)w, 0.0, 0.5);
 	gtk_label_set_line_wrap((GtkLabel *)w, TRUE);
@@ -356,7 +351,7 @@ efhd_xpkcs7mime_validity_clicked (GtkWidget *button,
 
 	gtk_widget_show_all(vbox);
 
-	g_object_unref(xml);
+	g_object_unref(builder);
 
 	g_signal_connect(po->widget, "response", G_CALLBACK(efhd_xpkcs7mime_info_response), po);
 	gtk_widget_show(po->widget);
@@ -477,7 +472,7 @@ static void
 efhd_format_optional (EMFormat *emf,
                       CamelStream *fstream,
                       CamelMimePart *part,
-                      CamelStream *mstream)
+                      const GByteArray *mem_bytes)
 {
 	gchar *classid, *html;
 	struct _attach_puri *info;
@@ -499,7 +494,9 @@ efhd_format_optional (EMFormat *emf,
 	info->snoop_mime_type = "text/plain";
 	info->attachment = e_attachment_new ();
 	e_attachment_set_mime_part (info->attachment, info->puri.part);
-	info->mstream = (CamelStreamMem *) mstream;
+	info->mem_bytes = g_byte_array_new ();
+	g_byte_array_append (info->mem_bytes, mem_bytes ? mem_bytes->data : (const guint8 *) "", mem_bytes ? mem_bytes->len : 1);
+
 	if (emf->valid) {
 		info->sign = emf->valid->sign.status;
 		info->encrypt = emf->valid->encrypt.status;
@@ -570,12 +567,20 @@ efhd_format_secure (EMFormat *emf,
 		g_free (classid);
 
 		if (valid->sign.status != CAMEL_CIPHER_VALIDITY_SIGN_NONE) {
+			gchar *signers;
 			const gchar *desc;
 			gint status;
 
 			status = valid->sign.status;
 			desc = smime_sign_table[status].shortdesc;
+
 			camel_stream_printf (stream, "%s", gettext (desc));
+
+			signers = em_format_html_format_cert_infos ((CamelCipherCertInfo *)valid->sign.signers.head);
+			if (signers && *signers) {
+				camel_stream_printf (stream, " (%s)", signers);
+			}
+			g_free (signers);
 		}
 
 		if (valid->encrypt.status != CAMEL_CIPHER_VALIDITY_ENCRYPT_NONE) {
@@ -710,7 +715,7 @@ efhd_message_prefix(EMFormat *emf, CamelStream *stream, CamelMimePart *part, EMF
 	camel_stream_printf(stream, "<table border=1 width=\"100%%\" cellspacing=2 cellpadding=2><tr>");
 
 	comp = camel_folder_get_message_user_tag(emf->folder, emf->uid, "completed-on");
-	iconpath = e_icon_factory_get_icon_filename (comp && comp[0] ? "stock_flag-for-followup-done" : "stock_flag-for-followup", GTK_ICON_SIZE_MENU);
+	iconpath = e_icon_factory_get_icon_filename (comp && comp[0] ? "stock_mail-flag-for-followup-done" : "stock_mail-flag-for-followup", GTK_ICON_SIZE_MENU);
 	if (iconpath) {
 		CamelMimePart *iconpart;
 
@@ -796,10 +801,27 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 	EAttachment *attachment;
 	GtkWidget *widget;
 	gpointer parent;
+	EMFormat *emf = (EMFormat *) efh;
+	CamelMessageInfo *mi = NULL;
+	guint32 size = 0;
 
 	/* FIXME: handle default shown case */
 	d(printf("adding attachment button/content\n"));
 
+	mi = camel_folder_summary_uid (emf->folder->summary, emf->uid);
+	if (mi) {
+		const CamelMessageContentInfo *ci;
+
+		ci = camel_folder_summary_guess_content_info (mi, camel_mime_part_get_content_type (pobject->part));
+		if (ci) {
+			size = ci->size;
+			/* what if its not encoded in base64 ? is it a case to consider? */
+			if (ci->encoding && !g_ascii_strcasecmp (ci->encoding, "base64"))
+				size = size/1.37;
+		}
+		camel_message_info_free (mi);
+	}
+
 	info = (struct _attach_puri *)em_format_find_puri((EMFormat *)efh, pobject->classid);
 
 	if (!info || info->forward) {
@@ -814,7 +836,7 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 	e_attachment_set_can_show (attachment, info->handle != NULL);
 
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (efh->html));
-	parent = GTK_WIDGET_TOPLEVEL (parent) ? parent : NULL;
+	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
 
 	view = em_format_html_display_get_attachment_view (efhd);
 	gtk_widget_show (GTK_WIDGET (view));
@@ -825,6 +847,13 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 	e_attachment_load_async (
 		info->attachment, (GAsyncReadyCallback)
 		e_attachment_load_handle_error, parent);
+	if (size != 0) {
+		GFileInfo *fileinfo;
+
+		fileinfo = e_attachment_get_file_info (info->attachment);
+		g_file_info_set_size (fileinfo, size);
+		e_attachment_set_file_info (info->attachment, fileinfo);
+	}
 
 	widget = e_attachment_button_new (view);
 	e_attachment_button_set_attachment (
@@ -926,7 +955,11 @@ efhd_optional_button_show (GtkWidget *widget, GtkWidget *w)
 {
 	GtkWidget *label = g_object_get_data (G_OBJECT (widget), "text-label");
 
+#if GTK_CHECK_VERSION(2,19,7)
+	if (gtk_widget_get_visible (w)) {
+#else
 	if (GTK_WIDGET_VISIBLE (w)) {
+#endif
 		gtk_widget_hide (w);
 		gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("View _Unformatted"));
 	} else {
@@ -1007,9 +1040,11 @@ efhd_attachment_optional(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPOb
 	gtk_text_view_set_editable (GTK_TEXT_VIEW (view), FALSE);
 	gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (view), FALSE);
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW (view));
-	gtk_text_buffer_set_text (buffer, (gchar *)info->mstream->buffer->data, info->mstream->buffer->len);
-	camel_object_unref(info->mstream);
-	info->mstream = NULL;
+	if (info->mem_bytes) {
+		gtk_text_buffer_set_text (buffer, (gchar *)info->mem_bytes->data, info->mem_bytes->len);
+		g_byte_array_free (info->mem_bytes, TRUE);
+	}
+	info->mem_bytes = NULL;
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll), GTK_SHADOW_IN);
