@@ -33,16 +33,14 @@
 #include <camel/camel-stream.h>
 
 #include <mail/e-mail-reader.h>
+#include <mail/em-folder-tree.h>
 
 G_BEGIN_DECLS
 
 struct _EMFormat;
 
-const gchar *	em_utils_get_data_dir		(void);
-const gchar *	em_utils_get_config_dir		(void);
-
 gboolean em_utils_ask_open_many (GtkWindow *parent, gint how_many);
-gboolean em_utils_prompt_user(GtkWindow *parent, const gchar *promptkey, const gchar *tag, const gchar *arg0, ...);
+gboolean em_utils_prompt_user(GtkWindow *parent, const gchar *promptkey, const gchar *tag, ...);
 
 GPtrArray *em_utils_uids_copy (GPtrArray *uids);
 void em_utils_uids_free (GPtrArray *uids);
@@ -75,8 +73,6 @@ gboolean em_utils_folder_is_templates(CamelFolder *folder, const gchar *uri);
 gboolean em_utils_folder_is_sent(CamelFolder *folder, const gchar *uri);
 gboolean em_utils_folder_is_outbox(CamelFolder *folder, const gchar *uri);
 
-void em_utils_adjustment_page(GtkAdjustment *adj, gboolean down);
-
 gchar *em_utils_get_proxy_uri (const gchar *uri);
 
 /* FIXME: should this have an override charset? */
@@ -106,12 +102,16 @@ void em_utils_clear_get_password_canceled_accounts_flag (void);
 /* Unescapes &amp; back to a real & in URIs */
 gchar *em_utils_url_unescape_amp (const gchar *url);
 
+GHashTable * em_utils_generate_account_hash (void);
 struct _EAccount *em_utils_guess_account (CamelMimeMessage *message, CamelFolder *folder);
+struct _EAccount *em_utils_guess_account_with_recipients (CamelMimeMessage *message, CamelFolder *folder);
 
 void emu_remove_from_mail_cache (const GSList *addresses);
 void emu_remove_from_mail_cache_1 (const gchar *address);
 void emu_free_mail_cache (void);
 
+void emu_restore_folder_tree_state (EMFolderTree *folder_tree);
+
 G_END_DECLS
 
 #endif /* __EM_UTILS_H__ */
