@@ -14,8 +14,10 @@
  *
  *
  * Authors:
+ *   Jonathon Jongsma <jonathon.jongsma@collabora.co.uk>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * Copyright (C) 2009 Intel Corporation
  *
  */
 
@@ -23,6 +25,7 @@
 
 #include <config.h>
 
+#include <errno.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -45,15 +48,14 @@
 #include <camel/camel-i18n.h>
 
 #include "e-util/e-util.h"
-#include "e-util/e-alert.h"
+#include "e-util/e-alert-dialog.h"
 #include "e-util/e-util-private.h"
-#include "e-account-combo-box.h"
-#include "shell/e-shell.h"
 
 #include "em-composer-utils.h"
 #include "em-filter-context.h"
 #include "em-filter-rule.h"
 #include "em-utils.h"
+#include "e-mail-local.h"
 #include "mail-config.h"
 #include "mail-mt.h"
 #include "mail-ops.h"
@@ -85,8 +87,9 @@ typedef struct _MailSessionClass {
 
 } MailSessionClass;
 
-static EShellBackend *session_shell_backend;
 static CamelSessionClass *ms_parent_class;
+static gchar *mail_data_dir;
+static gchar *mail_config_dir;
 
 static gchar *get_password(CamelSession *session, CamelService *service, const gchar *domain, const gchar *prompt, const gchar *item, guint32 flags, CamelException *ex);
 static void forget_password(CamelSession *session, CamelService *service, const gchar *domain, const gchar *item, CamelException *ex);
@@ -113,6 +116,9 @@ finalise (MailSession *session)
 		gconf_client_notify_remove (mail_config_get_gconf_client (), session_check_junk_notify_id);
 
 	mail_async_event_destroy(session->async);
+
+	g_free (mail_data_dir);
+	g_free (mail_config_dir);
 }
 
 static void
@@ -352,8 +358,10 @@ user_message_exec (struct _user_message_msg *m)
 			g_return_if_reached ();
 	}
 
-	user_message_dialog = e_alert_new_dialog_for_args (
-		e_shell_get_active_window (NULL), error_type, m->prompt, NULL);
+	/* The mail daemon won't have a window here, so there's nothing to set
+	 * as the parent */
+	user_message_dialog =
+		e_alert_dialog_new_for_args (NULL, error_type, m->prompt, NULL);
 	g_object_set (
 		user_message_dialog, "allow_shrink", TRUE,
 		"allow_grow", TRUE, NULL);
@@ -421,13 +429,9 @@ lookup_addressbook(CamelSession *session, const gchar *name)
 static gboolean
 alert_user(CamelSession *session, CamelSessionAlertType type, const gchar *prompt, gboolean cancel)
 {
-	MailSession *mail_session = MAIL_SESSION (session);
 	struct _user_message_msg *m;
 	gboolean result = TRUE;
 
-	if (!mail_session->interactive)
-		return FALSE;
-
 	m = mail_msg_new (&user_message_info);
 	m->ismain = mail_in_main_thread ();
 	m->type = type;
@@ -518,7 +522,7 @@ main_get_filter_driver (CamelSession *session, const gchar *type, CamelException
 
 	gconf = mail_config_get_gconf_client ();
 
-	data_dir = e_shell_backend_get_data_dir (session_shell_backend);
+	data_dir = mail_session_get_data_dir ();
 	user = g_build_filename (data_dir, "filters.xml", NULL);
 	system = g_build_filename (EVOLUTION_PRIVDATADIR, "filtertypes.xml", NULL);
 	fc = (ERuleContext *) em_filter_context_new ();
@@ -630,14 +634,92 @@ static void ms_thread_status(CamelSession *session, CamelSessionThreadMsg *msg,
 	printf("Thread status '%s' %d%%\n", text, pc);
 }
 
+static void
+ms_forward_to_cb (CamelFolder *folder, CamelMimeMessage *msg, CamelMessageInfo *info,
+		  gint queued, const gchar *appended_uid, gpointer data)
+{
+	camel_message_info_free (info);
+	/* do not call mail send, just pile them all in the outbox */
+	/* mail_send (); */
+}
+
 static void
 ms_forward_to (CamelSession *session, CamelFolder *folder, CamelMimeMessage *message, const gchar *address, CamelException *ex)
 {
-	g_return_if_fail (session != NULL);
+	EAccount *account;
+	CamelMimeMessage *forward;
+	CamelStream *mem;
+	CamelInternetAddress *addr;
+	CamelFolder *out_folder;
+	CamelMessageInfo *info;
+	struct _camel_header_raw *xev;
+	gchar *subject;
+
+	g_return_if_fail (folder != NULL);
 	g_return_if_fail (message != NULL);
 	g_return_if_fail (address != NULL);
 
-	em_utils_forward_message_raw (folder, message, address, ex);
+	if (!*address) {
+		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, _("No destination address provided, forward of the message has been cancelled."));
+		return;
+	}
+
+	account = em_utils_guess_account_with_recipients (message, folder);
+	if (!account) {
+		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, _("No account found to use, forward of the message has been cancelled."));
+		return;
+	}
+
+	forward = camel_mime_message_new ();
+
+	/* make copy of the message, because we are going to modify it */
+	mem = camel_stream_mem_new ();
+	camel_data_wrapper_write_to_stream ((CamelDataWrapper *)message, mem);
+	camel_seekable_stream_seek (CAMEL_SEEKABLE_STREAM (mem), 0, CAMEL_STREAM_SET);
+	camel_data_wrapper_construct_from_stream ((CamelDataWrapper *)forward, mem);
+	camel_object_unref (mem);
+
+	/* clear previous recipients */
+	camel_mime_message_set_recipients (forward, CAMEL_RECIPIENT_TYPE_TO, NULL);
+	camel_mime_message_set_recipients (forward, CAMEL_RECIPIENT_TYPE_CC, NULL);
+	camel_mime_message_set_recipients (forward, CAMEL_RECIPIENT_TYPE_BCC, NULL);
+	camel_mime_message_set_recipients (forward, CAMEL_RECIPIENT_TYPE_RESENT_TO, NULL);
+	camel_mime_message_set_recipients (forward, CAMEL_RECIPIENT_TYPE_RESENT_CC, NULL);
+	camel_mime_message_set_recipients (forward, CAMEL_RECIPIENT_TYPE_RESENT_BCC, NULL);
+
+	/* remove all delivery and notification headers */
+	while (camel_medium_get_header (CAMEL_MEDIUM (forward), "Disposition-Notification-To"))
+		camel_medium_remove_header (CAMEL_MEDIUM (forward), "Disposition-Notification-To");
+
+	while (camel_medium_get_header (CAMEL_MEDIUM (forward), "Delivered-To"))
+		camel_medium_remove_header (CAMEL_MEDIUM (forward), "Delivered-To");
+
+	/* remove any X-Evolution-* headers that may have been set */
+	xev = mail_tool_remove_xevolution_headers (forward);
+	camel_header_raw_clear (&xev);
+
+	/* from */
+	addr = camel_internet_address_new ();
+	camel_internet_address_add (addr, account->id->name, account->id->address);
+	camel_mime_message_set_from (forward, addr);
+	camel_object_unref (addr);
+
+	/* to */
+	addr = camel_internet_address_new ();
+	camel_address_decode (CAMEL_ADDRESS (addr), address);
+	camel_mime_message_set_recipients (forward, CAMEL_RECIPIENT_TYPE_TO, addr);
+	camel_object_unref (addr);
+
+	/* subject */
+	subject = mail_tool_generate_forward_subject (message);
+	camel_mime_message_set_subject (forward, subject);
+	g_free (subject);
+
+	/* and send it */
+	info = camel_message_info_new (NULL);
+	out_folder = e_mail_local_get_folder (E_MAIL_FOLDER_OUTBOX);
+	camel_message_info_set_flags (info, CAMEL_MESSAGE_SEEN, CAMEL_MESSAGE_SEEN);
+	mail_append_mail (out_folder, forward, info, ms_forward_to_cb, NULL);
 }
 
 gchar *
@@ -712,30 +794,19 @@ mail_session_check_junk_notify (GConfClient *gconf, guint id, GConfEntry *entry,
 }
 
 void
-mail_session_init (EShellBackend *shell_backend)
+mail_session_init (void)
 {
-	EShell *shell;
 	GConfClient *gconf;
-	gboolean online;
-	const gchar *data_dir;
 
-	session_shell_backend = shell_backend;
-
-	shell = e_shell_backend_get_shell (shell_backend);
-	online = e_shell_get_online (shell);
-
-	data_dir = e_get_user_data_dir ();
-	if (camel_init (data_dir, TRUE) != 0)
+	if (camel_init (e_get_user_data_dir (), TRUE) != 0)
 		exit (0);
 
 	camel_provider_init();
 
 	session = CAMEL_SESSION (camel_object_new (MAIL_SESSION_TYPE));
-	e_account_combo_box_set_session (session);  /* XXX Don't ask... */
 	e_account_writable(NULL, E_ACCOUNT_SOURCE_SAVE_PASSWD); /* Init the EAccount Setup */
 
-	data_dir = e_shell_backend_get_data_dir (shell_backend);
-	camel_session_construct (session, data_dir);
+	camel_session_construct (session, mail_session_get_data_dir ());
 
 	gconf = mail_config_get_gconf_client ();
 	gconf_client_add_dir (gconf, "/apps/evolution/mail/junk", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
@@ -745,7 +816,6 @@ mail_session_init (EShellBackend *shell_backend)
 								session, NULL, NULL);
 	session->junk_plugin = NULL;
 
-	camel_session_set_online ((CamelSession *) session, online);
 	mail_config_reload_junk_headers ();
 }
 
@@ -755,39 +825,6 @@ mail_session_shutdown (void)
 	camel_shutdown ();
 }
 
-gboolean
-mail_session_get_interactive (void)
-{
-	return MAIL_SESSION (session)->interactive;
-}
-
-void
-mail_session_set_interactive (gboolean interactive)
-{
-	MAIL_SESSION (session)->interactive = interactive;
-
-	if (!interactive) {
-		struct _user_message_msg *msg;
-
-		d(printf ("Gone non-interactive, checking for outstanding interactive tasks\n"));
-
-		e_passwords_cancel();
-
-		/* flush/cancel pending user messages */
-		while (!g_queue_is_empty (&user_message_queue)) {
-			msg = g_queue_pop_head (&user_message_queue);
-			e_flag_set (msg->done);
-			mail_msg_unref (msg);
-		}
-
-		/* and the current */
-		if (user_message_dialog) {
-			d(printf("Destroying message dialogue\n"));
-			gtk_widget_destroy ((GtkWidget *) user_message_dialog);
-		}
-	}
-}
-
 void
 mail_session_flush_filter_log (void)
 {
@@ -834,3 +871,30 @@ mail_session_set_junk_headers (const gchar **name, const gchar **value, gint len
 
 	camel_session_set_junk_headers (session, name, value, len);
 }
+
+const gchar *
+mail_session_get_data_dir (void)
+{
+	if (G_UNLIKELY (mail_data_dir == NULL))
+		mail_data_dir = g_build_filename (
+			e_get_user_data_dir (), "mail", NULL);
+
+	return mail_data_dir;
+}
+
+const gchar *
+mail_session_get_config_dir (void)
+{
+	if (G_UNLIKELY (mail_config_dir == NULL)) {
+		mail_config_dir = g_build_filename (
+			mail_session_get_data_dir (), "config", NULL);
+
+		if (g_mkdir_with_parents (mail_config_dir, 0777) != 0)
+			g_critical (
+				"Cannot create directory %s: %s",
+				mail_config_dir, g_strerror (errno));
+	}
+
+	return mail_config_dir;
+}
+
