@@ -216,6 +216,7 @@ action_mail_folder_mark_all_as_read_cb (GtkAction *action,
 	EShellView *shell_view;
 	CamelFolder *folder;
 	GtkWindow *parent;
+	MessageList *message_list;
 	GPtrArray *uids;
 	const gchar *key;
 	const gchar *prompt;
@@ -236,7 +237,10 @@ action_mail_folder_mark_all_as_read_cb (GtkAction *action,
 	if (!em_utils_prompt_user (parent, key, prompt, NULL))
 		return;
 
-	uids = e_mail_reader_get_selected_uids (reader);
+	message_list = MESSAGE_LIST (e_mail_reader_get_message_list (reader));
+	g_return_if_fail (message_list != NULL);
+
+	uids = message_list_get_uids (message_list);
 
 	camel_folder_freeze (folder);
 	for (ii = 0; ii < uids->len; ii++)
@@ -909,7 +913,7 @@ static GtkActionEntry mail_entries[] = {
 	{ "mail-folder-mark-all-as-read",
 	  "mail-read",
 	  N_("Mar_k All Messages as Read"),
-	  NULL,
+	  "<Control>slash",
 	  N_("Mark all messages in the folder as read"),
 	  G_CALLBACK (action_mail_folder_mark_all_as_read_cb) },
 
@@ -983,6 +987,8 @@ static GtkActionEntry mail_entries[] = {
 	  NULL,  /* XXX Add a tooltip! */
 	  G_CALLBACK (action_mail_label_new_cb) },
 
+	/* Translators: "None" is used in the message label context menu.
+	 *              It removes all labels from the selected messages. */
 	{ "mail-label-none",
 	  NULL,
 	  N_("N_one"),
