@@ -27,7 +27,7 @@
 #include <glib/gi18n-lib.h>
 #include <libedataserverui/e-contact-store.h>
 #include <e-util/e-util.h>
-#include <e-util/e-error.h>
+#include <e-util/e-alert-dialog.h>
 #include <e-util/e-util-private.h>
 #include <e-gw-container.h>
 #include <e-gw-connection.h>
@@ -339,10 +339,13 @@ add_clicked(GtkButton *button, ShareFolder *sf)
 		email = e_destination_get_email (tmp->data);
 		/* You can't share a folder with yourself*/
 		if (g_strrstr (email, "@") == NULL || (!g_ascii_strcasecmp (email , self_email)))
-			e_error_run (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (button))), "org.gnome.evolution.mail_shared_folder:invalid-user",email ,NULL);
+			e_alert_run_dialog_for_args (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (button))),
+						     "org.gnome.evolution.mail_shared_folder:invalid-user",
+						     email, NULL);
 		else {
 			if (!g_ascii_strcasecmp (email, "" )) {
-				e_error_run (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (button))), "org.gnome.evolution.mail_shared_folder:no-user",NULL);
+				e_alert_run_dialog_for_args (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (button))),
+							     "org.gnome.evolution.mail_shared_folder:no-user", NULL);
 
 				return;
 			}
@@ -479,7 +482,6 @@ not_ok_clicked(GtkButton *button, ShareFolder *sf)
 	GtkTextIter *start, *end;
 	GtkTextBuffer *buffer;
 
-	buffer = gtk_text_buffer_new (NULL);
 	start = g_new0 (GtkTextIter, 1);
 	end = g_new0 (GtkTextIter, 1);
 	subj = g_strdup (gtk_entry_get_text (sf->subject));
@@ -585,7 +587,7 @@ add_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 		gtk_tree_path_free (path);
 		return;
 	}
-	if (! usr->flag)  /* if user was already existing one change the flag to update*/
+	if (!usr->flag)  /* if user was already existing one change the flag to update*/
 		usr->flag = usr->flag | 0x2;
 	user = usr->user_node;
 	if (!right) {
@@ -618,7 +620,7 @@ edit_right_clicked(GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 		gtk_tree_path_free (path);
 		return;
 	}
-	if (! usr->flag)  /* if user was already existing one change the flag to update*/
+	if (!usr->flag)  /* if user was already existing one change the flag to update*/
 		usr->flag = usr->flag | 0x2;
 	user = usr->user_node;
 
@@ -652,7 +654,7 @@ delete_right_clicked(GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 		gtk_tree_path_free (path);
 		return;
 	}
-	if (! usr->flag)  /* if user was already existing one change the flag to update*/
+	if (!usr->flag)  /* if user was already existing one change the flag to update*/
 		usr->flag = usr->flag | 0x2;
 	user = usr->user_node;
 	if (!right) {
