@@ -258,6 +258,50 @@ size_allocate_cb (GtkHTMLEmbedded *embedded,
 		image_object->widget, widget_width, widget_height);
 }
 
+static void
+mouse_wheel_scroll_cb (GtkWidget *image_view,
+                       GdkScrollDirection direction,
+                       ImageInlinePObject *image_object)
+{
+	GtkOrientation orientation;
+	GtkScrollType scroll_type;
+	GtkHTML *html;
+	gint steps = 2;
+
+	html = image_object->object.format->html;
+
+	switch (direction) {
+		case GDK_SCROLL_UP:
+			orientation = GTK_ORIENTATION_VERTICAL;
+			scroll_type = GTK_SCROLL_STEP_BACKWARD;
+			break;
+
+		case GDK_SCROLL_DOWN:
+			orientation = GTK_ORIENTATION_VERTICAL;
+			scroll_type = GTK_SCROLL_STEP_FORWARD;
+			break;
+
+		case GDK_SCROLL_LEFT:
+			orientation = GTK_ORIENTATION_HORIZONTAL;
+			scroll_type = GTK_SCROLL_STEP_BACKWARD;
+			break;
+
+		case GDK_SCROLL_RIGHT:
+			orientation = GTK_ORIENTATION_HORIZONTAL;
+			scroll_type = GTK_SCROLL_STEP_FORWARD;
+			break;
+
+		default:
+			g_return_if_reached ();
+	}
+
+	while (steps > 0) {
+		g_signal_emit_by_name (
+			html, "scroll", orientation, scroll_type, 2.0, NULL);
+		steps--;
+	}
+}
+
 static void
 org_gnome_image_inline_pobject_free (EMFormatHTMLPObject *object)
 {
@@ -284,6 +328,9 @@ org_gnome_image_inline_pobject_free (EMFormatHTMLPObject *object)
 		g_signal_handlers_disconnect_by_func (
 			image_object->widget,
 			drag_data_get_cb, image_object);
+		g_signal_handlers_disconnect_by_func (
+			image_object->widget,
+			mouse_wheel_scroll_cb, image_object);
 
 		parent = gtk_widget_get_parent (image_object->widget);
 		if (parent != NULL)
@@ -388,6 +435,10 @@ org_gnome_image_inline_embed (EMFormatHTML *format,
 		embedded, "size-allocate",
 		G_CALLBACK (size_allocate_cb), image_object);
 
+	g_signal_connect (
+		image_view, "mouse-wheel-scroll",
+		G_CALLBACK (mouse_wheel_scroll_cb), image_object);
+
 	return TRUE;
 }
 
