@@ -25,14 +25,10 @@
 #include <config.h>
 #endif
 
-#define GLADE_FILE_NAME "smime-ui.glade"
-
 #include <gtk/gtk.h>
 
 #include <glib/gi18n.h>
 
-#include <glade/glade.h>
-#include "evolution-config-control.h"
 #include "ca-trust-dialog.h"
 #include "cert-trust-dialog.h"
 #include "certificate-manager.h"
@@ -49,10 +45,13 @@
 #include <pkcs11.h>
 #include <pk11func.h>
 
+#include "shell/e-shell.h"
+#include "e-util/e-util.h"
 #include "e-util/e-util-private.h"
+#include "widgets/misc/e-preferences-window.h"
 
 typedef struct {
-	GladeXML *gui;
+	GtkBuilder *builder;
 
 	GtkWidget *yourcerts_treeview;
 	GtkTreeStore *yourcerts_treemodel;
@@ -960,19 +959,25 @@ load_certs (CertificateManagerData *cfm,
 	for (node = CERT_LIST_HEAD(certList);
 	     !CERT_LIST_END(node, certList);
 	     node = CERT_LIST_NEXT(node)) {
-		ECert *cert = e_cert_new ((CERTCertificate*)node->cert);
+		ECert *cert = e_cert_new (CERT_DupCertificate ((CERTCertificate*)node->cert));
 		ECertType ct = e_cert_get_cert_type (cert);
 
 		/* show everything else in a contact tab */
 		if (ct == type || (type == E_CERT_CONTACT && ct != E_CERT_CA && ct != E_CERT_USER)) {
 			add_cert (cfm, cert);
+		} else {
+			g_object_unref (cert);
 		}
 	}
+
+	CERT_DestroyCertList (certList);
 }
 
-static void
+static gboolean
 populate_ui (CertificateManagerData *cfm)
 {
+	/* This is an idle callback. */
+
 	unload_certs (cfm, E_CERT_USER);
 	load_certs (cfm, E_CERT_USER, add_user_cert);
 
@@ -985,60 +990,71 @@ populate_ui (CertificateManagerData *cfm)
 	/* expand all three trees */
 	gtk_tree_view_expand_all (GTK_TREE_VIEW (cfm->yourcerts_treeview));
 	gtk_tree_view_expand_all (GTK_TREE_VIEW (cfm->contactcerts_treeview));
+
+	return FALSE;
 }
 
-EvolutionConfigControl*
-certificate_manager_config_control_new (void)
+void
+certificate_manager_config_init (EShell *shell)
 {
 	CertificateManagerData *cfm_data;
-	GtkWidget *control_widget;
-	gchar *gladefile;
+	GtkWidget *preferences_window;
+	GtkWidget *widget;
+
+	g_return_if_fail (E_IS_SHELL (shell));
 
 	/* We need to peek the db here to make sure it (and NSS) are fully initialized. */
 	e_cert_db_peek ();
 
 	cfm_data = g_new0 (CertificateManagerData, 1);
 
-	gladefile = g_build_filename (EVOLUTION_GLADEDIR,
-				      GLADE_FILE_NAME,
-				      NULL);
-	cfm_data->gui = glade_xml_new (gladefile, NULL, NULL);
-	g_free (gladefile);
+	cfm_data->builder = gtk_builder_new ();
+	e_load_ui_builder_definition (cfm_data->builder, "smime-ui.ui");
 
-	cfm_data->yourcerts_treeview = glade_xml_get_widget (cfm_data->gui, "yourcerts-treeview");
-	cfm_data->contactcerts_treeview = glade_xml_get_widget (cfm_data->gui, "contactcerts-treeview");
-	cfm_data->authoritycerts_treeview = glade_xml_get_widget (cfm_data->gui, "authoritycerts-treeview");
+	cfm_data->yourcerts_treeview = e_builder_get_widget (cfm_data->builder, "yourcerts-treeview");
+	cfm_data->contactcerts_treeview = e_builder_get_widget (cfm_data->builder, "contactcerts-treeview");
+	cfm_data->authoritycerts_treeview = e_builder_get_widget (cfm_data->builder, "authoritycerts-treeview");
 
-	cfm_data->view_your_button = glade_xml_get_widget (cfm_data->gui, "your-view-button");
-	cfm_data->backup_your_button = glade_xml_get_widget (cfm_data->gui, "your-backup-button");
-	cfm_data->backup_all_your_button = glade_xml_get_widget (cfm_data->gui, "your-backup-all-button");
-	cfm_data->import_your_button = glade_xml_get_widget (cfm_data->gui, "your-import-button");
-	cfm_data->delete_your_button = glade_xml_get_widget (cfm_data->gui, "your-delete-button");
+	cfm_data->view_your_button = e_builder_get_widget (cfm_data->builder, "your-view-button");
+	cfm_data->backup_your_button = e_builder_get_widget (cfm_data->builder, "your-backup-button");
+	cfm_data->backup_all_your_button = e_builder_get_widget (cfm_data->builder, "your-backup-all-button");
+	cfm_data->import_your_button = e_builder_get_widget (cfm_data->builder, "your-import-button");
+	cfm_data->delete_your_button = e_builder_get_widget (cfm_data->builder, "your-delete-button");
 
-	cfm_data->view_contact_button = glade_xml_get_widget (cfm_data->gui, "contact-view-button");
-	cfm_data->edit_contact_button = glade_xml_get_widget (cfm_data->gui, "contact-edit-button");
-	cfm_data->import_contact_button = glade_xml_get_widget (cfm_data->gui, "contact-import-button");
-	cfm_data->delete_contact_button = glade_xml_get_widget (cfm_data->gui, "contact-delete-button");
+	cfm_data->view_contact_button = e_builder_get_widget (cfm_data->builder, "contact-view-button");
+	cfm_data->edit_contact_button = e_builder_get_widget (cfm_data->builder, "contact-edit-button");
+	cfm_data->import_contact_button = e_builder_get_widget (cfm_data->builder, "contact-import-button");
+	cfm_data->delete_contact_button = e_builder_get_widget (cfm_data->builder, "contact-delete-button");
 
-	cfm_data->view_ca_button = glade_xml_get_widget (cfm_data->gui, "authority-view-button");
-	cfm_data->edit_ca_button = glade_xml_get_widget (cfm_data->gui, "authority-edit-button");
-	cfm_data->import_ca_button = glade_xml_get_widget (cfm_data->gui, "authority-import-button");
-	cfm_data->delete_ca_button = glade_xml_get_widget (cfm_data->gui, "authority-delete-button");
+	cfm_data->view_ca_button = e_builder_get_widget (cfm_data->builder, "authority-view-button");
+	cfm_data->edit_ca_button = e_builder_get_widget (cfm_data->builder, "authority-edit-button");
+	cfm_data->import_ca_button = e_builder_get_widget (cfm_data->builder, "authority-import-button");
+	cfm_data->delete_ca_button = e_builder_get_widget (cfm_data->builder, "authority-delete-button");
 
 	initialize_yourcerts_ui(cfm_data);
 	initialize_contactcerts_ui(cfm_data);
 	initialize_authoritycerts_ui(cfm_data);
 
-	populate_ui (cfm_data);
+	/* Run this in an idle callback so Evolution has a chance to
+	 * fully initialize itself and start its main loop before we
+	 * load certificates, since doing so may trigger a password
+	 * dialog, and dialogs require a main loop. */
+	g_idle_add ((GSourceFunc) populate_ui, cfm_data);
 
-	control_widget = glade_xml_get_widget (cfm_data->gui, "cert-manager-notebook");
-	g_object_ref (control_widget);
+	widget = e_builder_get_widget (cfm_data->builder, "cert-manager-notebook");
+	g_object_ref (widget);
 
-	gtk_container_remove (GTK_CONTAINER (control_widget->parent), control_widget);
+	gtk_container_remove (GTK_CONTAINER (widget->parent), widget);
 
 	/* FIXME: remove when implemented */
 	gtk_widget_set_sensitive(cfm_data->backup_your_button, FALSE);
 	gtk_widget_set_sensitive(cfm_data->backup_all_your_button, FALSE);
 
-	return evolution_config_control_new (control_widget);
+	preferences_window = e_shell_get_preferences_window (shell);
+	e_preferences_window_add_page (
+		E_PREFERENCES_WINDOW (preferences_window),
+		"certificates",
+		"preferences-certificates",
+		_("Certificates"),
+		widget, 700);
 }
