@@ -239,7 +239,9 @@ e_timezone_dialog_add_timezones (ETimezoneDialog *etd)
 		g_hash_table_insert (index, (gchar *)(l->data), GINT_TO_POINTER (i));
 	}
 
-	g_object_set_data_full (G_OBJECT (list_store), "index", index, (GDestroyNotify) g_hash_table_destroy);
+	g_object_set_data_full (
+		G_OBJECT (list_store), "index", index,
+		(GDestroyNotify) g_hash_table_destroy);
 
 	gtk_combo_box_set_model (combo, (GtkTreeModel *) list_store);
 
@@ -272,12 +274,16 @@ e_timezone_dialog_construct (ETimezoneDialog *etd)
 	e_load_ui_builder_definition (priv->builder, "e-timezone-dialog.ui");
 
 	if (!get_widgets (etd)) {
-		g_message ("e_timezone_dialog_construct(): Could not find all widgets in the XML file!");
+		g_message (
+			"%s(): Could not find all widgets in the XML file!",
+			G_STRFUNC);
 		goto error;
 	}
 
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (priv->app)->vbox), 0);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (priv->app)->action_area), 12);
+	gtk_container_set_border_width (
+		GTK_CONTAINER (GTK_DIALOG (priv->app)->vbox), 0);
+	gtk_container_set_border_width (
+		GTK_CONTAINER (GTK_DIALOG (priv->app)->action_area), 12);
 
 	priv->map = e_map_new ();
 	map = GTK_WIDGET (priv->map);
@@ -296,12 +302,22 @@ e_timezone_dialog_construct (ETimezoneDialog *etd)
 	/* Ensure a reasonable minimum amount of map is visible */
 	gtk_widget_set_size_request (priv->map_window, 200, 200);
 
-        g_signal_connect (map, "motion-notify-event", G_CALLBACK (on_map_motion), etd);
-        g_signal_connect (map, "leave-notify-event", G_CALLBACK (on_map_leave), etd);
-        g_signal_connect (map, "visibility-notify-event", G_CALLBACK (on_map_visibility_changed), etd);
-	g_signal_connect (map, "button-press-event", G_CALLBACK (on_map_button_pressed), etd);
+	g_signal_connect (
+		map, "motion-notify-event",
+		G_CALLBACK (on_map_motion), etd);
+	g_signal_connect (
+		map, "leave-notify-event",
+		G_CALLBACK (on_map_leave), etd);
+	g_signal_connect (
+		map, "visibility-notify-event",
+		G_CALLBACK (on_map_visibility_changed), etd);
+	g_signal_connect (
+		map, "button-press-event",
+		G_CALLBACK (on_map_button_pressed), etd);
 
-	g_signal_connect (GTK_COMBO_BOX (priv->timezone_combo), "changed", G_CALLBACK (on_combo_changed), etd);
+	g_signal_connect (
+		priv->timezone_combo, "changed",
+		G_CALLBACK (on_combo_changed), etd);
 
 	return etd;
 
@@ -340,6 +356,8 @@ get_local_timezone(void)
 
 	if (location)
 		zone = icaltimezone_get_builtin_timezone (location);
+	else
+		zone = icaltimezone_get_utc_timezone ();
 
 	g_free (location);
 
@@ -486,14 +504,14 @@ on_map_motion (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 {
 	ETimezoneDialog *etd;
 	ETimezoneDialogPrivate *priv;
-	double longitude, latitude;
+	gdouble longitude, latitude;
 	icaltimezone *new_zone;
 	gchar *display=NULL;
 
 	etd = E_TIMEZONE_DIALOG (data);
 	priv = etd->priv;
 
-	e_map_window_to_world (priv->map, (double) event->x, (double) event->y,
+	e_map_window_to_world (priv->map, (gdouble) event->x, (gdouble) event->y,
 			       &longitude, &latitude);
 
 	if (priv->point_hover && priv->point_hover != priv->point_selected)
@@ -576,12 +594,12 @@ on_map_button_pressed (GtkWidget *w, GdkEventButton *event, gpointer data)
 {
 	ETimezoneDialog *etd;
 	ETimezoneDialogPrivate *priv;
-	double longitude, latitude;
+	gdouble longitude, latitude;
 
 	etd = E_TIMEZONE_DIALOG (data);
 	priv = etd->priv;
 
-	e_map_window_to_world (priv->map, (double) event->x, (double) event->y,
+	e_map_window_to_world (priv->map, (gdouble) event->x, (gdouble) event->y,
 			       &longitude, &latitude);
 
 	if (event->button != 1) {
@@ -612,7 +630,7 @@ get_zone_from_point (ETimezoneDialog *etd,
 		     EMapPoint *point)
 {
 	icalarray *zones;
-	double longitude, latitude;
+	gdouble longitude, latitude;
 	gint i;
 
 	if (point == NULL)
@@ -625,7 +643,7 @@ get_zone_from_point (ETimezoneDialog *etd,
 
 	for (i = 0; i < zones->num_elements; i++) {
 		icaltimezone *zone;
-		double zone_longitude, zone_latitude;
+		gdouble zone_longitude, zone_latitude;
 
 		zone = icalarray_element_at (zones, i);
 		zone_longitude = icaltimezone_get_longitude (zone);
@@ -681,11 +699,8 @@ e_timezone_dialog_set_timezone (ETimezoneDialog *etd,
 
 	g_return_if_fail (E_IS_TIMEZONE_DIALOG (etd));
 
-	if (!zone) {
-		zone = (icaltimezone *)get_local_timezone();
-		if (!zone)
-			zone = icaltimezone_get_utc_timezone();
-	}
+	if (!zone)
+		zone = get_local_timezone();
 
 	if (zone)
 		display = zone_display_name_with_offset(zone);
@@ -721,7 +736,7 @@ set_map_timezone (ETimezoneDialog *etd, icaltimezone *zone)
 {
 	ETimezoneDialogPrivate *priv;
 	EMapPoint *point;
-	double zone_longitude, zone_latitude;
+	gdouble zone_longitude, zone_latitude;
 
 	priv = etd->priv;
 
@@ -810,24 +825,6 @@ timezone_combo_set_active_text (GtkComboBox *combo, const gchar *zone_name)
 	return (id != NULL);
 }
 
-/**
- * e_timezone_dialog_reparent:
- * @etd: #ETimezoneDialog.
- * @new_parent: The new parent widget.
- *
- * Takes the internal widgets out of the dialog and put them into @new_parent
- */
-void
-e_timezone_dialog_reparent (ETimezoneDialog *etd,
-			    GtkWidget *new_parent)
-{
-	ETimezoneDialogPrivate *priv;
-
-	priv = etd->priv;
-
-	gtk_widget_reparent (priv->table, new_parent);
-}
-
 static void
 map_destroy_cb(gpointer data, GObject *where_object_was)
 {
