@@ -84,43 +84,13 @@ attachment_paned_notify_cb (EAttachmentPaned *paned,
 
 	/* Update the expander label. */
 	if (gtk_expander_get_expanded (expander))
-		text = _("Hide _Attachment Bar");
+		text = _("Hide Attachment _Bar");
 	else
-		text = _("Show _Attachment Bar");
+		text = _("Show Attachment _Bar");
 
 	gtk_label_set_text_with_mnemonic (label, text);
 }
 
-static void
-attachment_paned_sync_icon_view (EAttachmentPaned *paned)
-{
-	EAttachmentView *source;
-	EAttachmentView *target;
-
-	source = E_ATTACHMENT_VIEW (paned->priv->tree_view);
-	target = E_ATTACHMENT_VIEW (paned->priv->icon_view);
-
-	/* Only sync if the tree view is active.  This prevents the
-	 * two views from endlessly trying to sync with each other. */
-	if (e_attachment_paned_get_active_view (paned) == 1)
-		e_attachment_view_sync_selection (source, target);
-}
-
-static void
-attachment_paned_sync_tree_view (EAttachmentPaned *paned)
-{
-	EAttachmentView *source;
-	EAttachmentView *target;
-
-	source = E_ATTACHMENT_VIEW (paned->priv->icon_view);
-	target = E_ATTACHMENT_VIEW (paned->priv->tree_view);
-
-	/* Only sync if the icon view is active.  This prevents the
-	 * two views from endlessly trying to sync with each other. */
-	if (e_attachment_paned_get_active_view (paned) == 0)
-		e_attachment_view_sync_selection (source, target);
-}
-
 static void
 attachment_paned_update_status (EAttachmentPaned *paned)
 {
@@ -142,10 +112,15 @@ attachment_paned_update_status (EAttachmentPaned *paned)
 	total_size = e_attachment_store_get_total_size (store);
 	display_size = g_format_size_for_display (total_size);
 
-	markup = g_strdup_printf (
-		"<b>%d</b> %s (%s)", num_attachments, ngettext (
-		"Attachment", "Attachments", num_attachments),
-		display_size);
+	if (total_size > 0)
+		markup = g_strdup_printf (
+			"<b>%d</b> %s (%s)", num_attachments, ngettext (
+			"Attachment", "Attachments", num_attachments),
+			display_size);
+	else
+		markup = g_strdup_printf (
+			"<b>%d</b> %s", num_attachments, ngettext (
+			"Attachment", "Attachments", num_attachments));
 	gtk_label_set_markup (label, markup);
 	g_free (markup);
 
@@ -504,7 +479,6 @@ static void
 attachment_paned_init (EAttachmentPaned *paned)
 {
 	EAttachmentView *view;
-	GtkTreeSelection *selection;
 	GtkSizeGroup *size_group;
 	GtkWidget *container;
 	GtkWidget *widget;
@@ -614,10 +588,15 @@ attachment_paned_init (EAttachmentPaned *paned)
 
 	/* Request the width to be as large as possible, and let the
 	 * GtkExpander allocate what space there is.  This effectively
-	 * packs the widget to expand. */
+	 * packs the widget to expand.
+	 *
+	 * XXX This hack causes nasty side-effects in RTL locales,
+	 *     so check the reading direction before applying it.
+	 *     See GNOME bug #614049 for details + screenshot. */
 	widget = gtk_hbox_new (FALSE, 6);
 	gtk_size_group_add_widget (size_group, widget);
-	gtk_widget_set_size_request (widget, G_MAXINT, -1);
+	if (gtk_widget_get_direction (widget) != GTK_TEXT_DIR_RTL)
+		gtk_widget_set_size_request (widget, G_MAXINT, -1);
 	gtk_expander_set_label_widget (GTK_EXPANDER (container), widget);
 	gtk_widget_show (widget);
 
@@ -652,17 +631,6 @@ attachment_paned_init (EAttachmentPaned *paned)
 	paned->priv->status_label = g_object_ref (widget);
 	gtk_widget_hide (widget);
 
-	selection = gtk_tree_view_get_selection (
-		GTK_TREE_VIEW (paned->priv->tree_view));
-
-	g_signal_connect_swapped (
-		selection, "changed",
-		G_CALLBACK (attachment_paned_sync_icon_view), paned);
-
-	g_signal_connect_swapped (
-		paned->priv->icon_view, "selection-changed",
-		G_CALLBACK (attachment_paned_sync_tree_view), paned);
-
 	g_signal_connect_swapped (
 		paned->priv->expander, "notify::expanded",
 		G_CALLBACK (attachment_paned_notify_cb), paned);
@@ -740,11 +708,31 @@ void
 e_attachment_paned_set_active_view (EAttachmentPaned *paned,
                                     gint active_view)
 {
+	EAttachmentView *source;
+	EAttachmentView *target;
+
 	g_return_if_fail (E_IS_ATTACHMENT_PANED (paned));
 	g_return_if_fail (active_view >= 0 && active_view < NUM_VIEWS);
 
+	if (active_view == paned->priv->active_view)
+		return;
+
 	paned->priv->active_view = active_view;
 
+	/* Synchronize the item selection of the view we're
+	 * switching TO with the view we're switching FROM. */
+	if (active_view == 0) {
+		/* from tree view to icon view */
+		source = E_ATTACHMENT_VIEW (paned->priv->tree_view);
+		target = E_ATTACHMENT_VIEW (paned->priv->icon_view);
+	} else {
+		/* from icon view to tree view */
+		source = E_ATTACHMENT_VIEW (paned->priv->icon_view);
+		target = E_ATTACHMENT_VIEW (paned->priv->tree_view);
+	}
+
+	e_attachment_view_sync_selection (source, target);
+
 	g_object_notify (G_OBJECT (paned), "active-view");
 }
 
