@@ -100,15 +100,18 @@ attachment_tree_view_render_size (GtkTreeViewColumn *column,
                                   GtkTreeModel *model,
                                   GtkTreeIter *iter)
 {
-	gchar *display_size;
+	gchar *display_size = NULL;
 	gint column_id;
 	guint64 size;
 
 	column_id = E_ATTACHMENT_STORE_COLUMN_SIZE;
 	gtk_tree_model_get (model, iter, column_id, &size, -1);
 
-	display_size = g_format_size_for_display ((goffset) size);
+	if (size > 0)
+		display_size = g_format_size_for_display ((goffset) size);
+
 	g_object_set (renderer, "text", display_size, NULL);
+
 	g_free (display_size);
 }
 
@@ -140,6 +143,20 @@ attachment_tree_view_button_release_event (GtkWidget *widget,
 		button_release_event (widget, event);
 }
 
+static gboolean
+attachment_tree_view_motion_notify_event (GtkWidget *widget,
+                                          GdkEventMotion *event)
+{
+	EAttachmentView *view = E_ATTACHMENT_VIEW (widget);
+
+	if (e_attachment_view_motion_notify_event (view, event))
+		return TRUE;
+
+	/* Chain up to parent's motion_notify_event() method. */
+	return GTK_WIDGET_CLASS (parent_class)->
+		motion_notify_event (widget, event);
+}
+
 static gboolean
 attachment_tree_view_key_press_event (GtkWidget *widget,
                                       GdkEventKey *event)
@@ -437,6 +454,7 @@ attachment_tree_view_class_init (EAttachmentTreeViewClass *class)
 	widget_class = GTK_WIDGET_CLASS (class);
 	widget_class->button_press_event = attachment_tree_view_button_press_event;
 	widget_class->button_release_event = attachment_tree_view_button_release_event;
+	widget_class->motion_notify_event = attachment_tree_view_motion_notify_event;
 	widget_class->key_press_event = attachment_tree_view_key_press_event;
 	widget_class->drag_begin = attachment_tree_view_drag_begin;
 	widget_class->drag_end = attachment_tree_view_drag_end;
