@@ -24,6 +24,7 @@
 #include <errno.h>
 #include <config.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <camel/camel-iconv.h>
 #include <camel/camel-data-wrapper.h>
 #include <camel/camel-mime-message.h>
@@ -54,7 +55,7 @@
 #define EMBLEM_ENCRYPT_WEAK	"security-low"
 #define EMBLEM_ENCRYPT_STRONG	"security-high"
 #define EMBLEM_ENCRYPT_UNKNOWN	"security-medium"
-#define EMBLEM_SIGN_BAD		"stock_signature_bad"
+#define EMBLEM_SIGN_BAD		"stock_signature-bad"
 #define EMBLEM_SIGN_GOOD	"stock_signature-ok"
 #define EMBLEM_SIGN_UNKNOWN	"stock_signature"
 
@@ -107,6 +108,7 @@ static gboolean
 create_system_thumbnail (EAttachment *attachment, GIcon **icon)
 {
 	GFile *file;
+	GFile *icon_file;
 	gchar *thumbnail = NULL;
 
 	g_return_val_if_fail (attachment != NULL, FALSE);
@@ -122,27 +124,33 @@ create_system_thumbnail (EAttachment *attachment, GIcon **icon)
 		}
 	}
 
-	if (thumbnail) {
-		GFile *gf = g_file_new_for_path (thumbnail);
+	if (thumbnail == NULL)
+		return FALSE;
 
-		g_return_val_if_fail (gf != NULL, FALSE);
-		if (*icon)
-			g_object_unref (*icon);
+	icon_file = g_file_new_for_path (thumbnail);
 
-		*icon = g_file_icon_new (gf);
-		g_object_unref (gf);
+	if (*icon)
+		g_object_unref (*icon);
 
-		if (file) {
-			GFileInfo *fi = e_attachment_get_file_info (attachment);
+	*icon = g_file_icon_new (icon_file);
 
-			if (fi)
-				g_file_info_set_attribute_byte_string (fi, G_FILE_ATTRIBUTE_THUMBNAIL_PATH, thumbnail);
-		}
+	g_object_unref (icon_file);
+
+	if (file) {
+		GFileInfo *file_info;
+		const gchar *attribute;
+
+		file_info = e_attachment_get_file_info (attachment);
+		attribute = G_FILE_ATTRIBUTE_THUMBNAIL_PATH;
+
+		if (file_info != NULL)
+			g_file_info_set_attribute_byte_string (
+				file_info, attribute, thumbnail);
 	}
 
 	g_free (thumbnail);
 
-	return thumbnail != NULL;
+	return TRUE;
 }
 
 static gchar *
@@ -275,9 +283,9 @@ attachment_update_icon_column (EAttachment *attachment)
 		icon = g_file_icon_new (file);
 		g_object_unref (file);
 
-	/* try the system thumbnailer */
+	/* Try the system thumbnailer. */
 	} else if (create_system_thumbnail (attachment, &icon)) {
-		/* actually do nothing, just use the icon */
+		/* Nothing to do, just use the icon. */
 
 	/* Else use the standard icon for the content type. */
 	} else if (icon != NULL)
@@ -393,9 +401,9 @@ attachment_update_progress_columns (EAttachment *attachment)
 		-1);
 }
 
-static void
-attachment_set_file_info (EAttachment *attachment,
-                          GFileInfo *file_info)
+void
+e_attachment_set_file_info (EAttachment *attachment,
+                            GFileInfo *file_info)
 {
 	GtkTreeRowReference *reference;
 	GIcon *icon;
@@ -987,6 +995,10 @@ e_attachment_new_for_message (CamelMimeMessage *message)
 	camel_mime_part_set_disposition (mime_part, "inline");
 	subject = camel_mime_message_get_subject (message);
 
+	/* To Translators: This text is set as a description of an attached
+	 * message when, for example, attaching it to a composer. When the
+	 * message to be attached has also filled Subject, then this text is
+	 * of form "Attached message - Subject", otherwise it's left as is. */
 	description = g_string_new (_("Attached message"));
 	if (subject != NULL)
 		g_string_append_printf (description, " - %s", subject);
@@ -1549,7 +1561,7 @@ attachment_load_finish (LoadContext *load_context)
 	/* Correctly report the size of zero length special files. */
 	if (g_file_info_get_size (file_info) == 0) {
 		g_file_info_set_size (file_info, size);
-		attachment_set_file_info (attachment, file_info);
+		e_attachment_set_file_info (attachment, file_info);
 	}
 
 	g_simple_async_result_set_op_res_gpointer (
@@ -1697,7 +1709,7 @@ attachment_load_query_info_cb (GFile *file,
 	if (attachment_load_check_for_error (load_context, error))
 		return;
 
-	attachment_set_file_info (attachment, file_info);
+	e_attachment_set_file_info (attachment, file_info);
 	load_context->file_info = file_info;
 
 	load_context->total_num_bytes = g_file_info_get_size (file_info);
@@ -1719,7 +1731,6 @@ attachment_load_from_mime_part (LoadContext *load_context)
 	const gchar *attribute;
 	const gchar *string;
 	gchar *allocated;
-	goffset size;
 
 	attachment = load_context->attachment;
 	mime_part = e_attachment_get_mime_part (attachment);
@@ -1774,15 +1785,10 @@ attachment_load_from_mime_part (LoadContext *load_context)
 		g_file_info_set_attribute_string (
 			file_info, attribute, string);
 
-	/* FIXME This can cause Camel to block while downloading the
-	 *       MIME part in order to determine the content size. */
-	size = (goffset) camel_mime_part_get_content_size (mime_part);
-	g_file_info_set_size (file_info, size);
-
 	string = camel_mime_part_get_disposition (mime_part);
 	e_attachment_set_disposition (attachment, string);
 
-	attachment_set_file_info (attachment, file_info);
+	e_attachment_set_file_info (attachment, file_info);
 
 	camel_object_ref (mime_part);
 
@@ -2040,6 +2046,7 @@ attachment_open_save_finished_cb (EAttachment *attachment,
                                   OpenContext *open_context)
 {
 	GFile *file;
+	gchar *path;
 	GError *error = NULL;
 
 	file = e_attachment_save_finish (attachment, result, &error);
@@ -2047,6 +2054,24 @@ attachment_open_save_finished_cb (EAttachment *attachment,
 	if (attachment_open_check_for_error (open_context, error))
 		return;
 
+	/* Make the temporary file read-only.
+	 *
+	 * This step is non-critical, so if an error occurs just
+	 * emit a warning and move on.
+	 *
+	 * XXX I haven't figured out how to do this through GIO.
+	 *     Attempting to set the "access::can-write" attribute via
+	 *     g_file_set_attribute() returned G_IO_ERROR_NOT_SUPPORTED
+	 *     and the only other possibility I see is "unix::mode",
+	 *     which is obviously not portable.
+	 */
+	path = g_file_get_path (file);
+#ifndef G_OS_WIN32
+	if (g_chmod (path, S_IRUSR | S_IRGRP | S_IROTH) < 0)
+		g_warning ("%s", g_strerror (errno));
+#endif
+	g_free (path);
+
 	attachment_open_file (file, open_context);
 	g_object_unref (file);
 }
