@@ -57,7 +57,7 @@ static void e_calendar_item_realize	(GnomeCanvasItem *item);
 static void e_calendar_item_unrealize	(GnomeCanvasItem *item);
 static void e_calendar_item_unmap	(GnomeCanvasItem *item);
 static void e_calendar_item_update	(GnomeCanvasItem *item,
-					 double		 *affine,
+					 gdouble		 *affine,
 					 ArtSVP		 *clip_path,
 					 gint		  flags);
 static void e_calendar_item_draw	(GnomeCanvasItem *item,
@@ -85,9 +85,9 @@ static void e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 					      gint		 start_weekday,
 					      gint		 cells_x,
 					      gint		 cells_y);
-static double e_calendar_item_point	(GnomeCanvasItem *item,
-					 double		  x,
-					 double		  y,
+static gdouble e_calendar_item_point	(GnomeCanvasItem *item,
+					 gdouble		  x,
+					 gdouble		  y,
 					 gint		  cx,
 					 gint		  cy,
 					 GnomeCanvasItem **actual_item);
@@ -100,8 +100,8 @@ static gint e_calendar_item_key_press_event (ECalendarItem *item,
 					     GdkEvent *event);
 static gint e_calendar_item_event	(GnomeCanvasItem *item,
 					 GdkEvent	 *event);
-static void e_calendar_item_bounds (GnomeCanvasItem *item, double *x1, double *y1,
-				    double *x2, double *y2);
+static void e_calendar_item_bounds (GnomeCanvasItem *item, gdouble *x1, gdouble *y1,
+				    gdouble *x2, gdouble *y2);
 
 static gboolean e_calendar_item_button_press	(ECalendarItem	*calitem,
 						 GdkEvent	*event);
@@ -188,8 +188,8 @@ static void e_calendar_item_date_range_changed	(ECalendarItem	*calitem);
 static void e_calendar_item_queue_signal_emission	(ECalendarItem	*calitem);
 static gboolean e_calendar_item_signal_emission_idle_cb	(gpointer data);
 static void e_calendar_item_set_selection_if_emission (ECalendarItem	*calitem,
-						       GDate		*start_date,
-						       GDate		*end_date,
+						       const GDate	*start_date,
+						       const GDate	*end_date,
 						       gboolean emission);
 
 /* Our arguments. */
@@ -880,7 +880,7 @@ e_calendar_item_unmap		(GnomeCanvasItem *item)
 
 static void
 e_calendar_item_update		(GnomeCanvasItem *item,
-				 double		 *affine,
+				 gdouble		 *affine,
 				 ArtSVP		 *clip_path,
 				 gint		  flags)
 {
@@ -898,7 +898,7 @@ e_calendar_item_update		(GnomeCanvasItem *item,
 		item_class->update (item, affine, clip_path, flags);
 
 	calitem = E_CALENDAR_ITEM (item);
-	style = GTK_WIDGET (item->canvas)->style;
+	style = gtk_widget_get_style (GTK_WIDGET (item->canvas));
 	xthickness = style->xthickness;
 	ythickness = style->ythickness;
 
@@ -1023,7 +1023,6 @@ e_calendar_item_draw		(GnomeCanvasItem *canvas_item,
 {
 	ECalendarItem *calitem;
 	GtkStyle *style;
-	GdkGC *base_gc, *bg_gc;
 	gint char_height, row, col, row_y, bar_height, col_x;
 	gint xthickness, ythickness;
 	PangoFontDescription *font_desc;
@@ -1037,7 +1036,7 @@ e_calendar_item_draw		(GnomeCanvasItem *canvas_item,
 		 x, y, width, height);
 #endif
 	calitem = E_CALENDAR_ITEM (canvas_item);
-	style = GTK_WIDGET (canvas_item->canvas)->style;
+	style = gtk_widget_get_style (GTK_WIDGET (canvas_item->canvas));
 
 	/* Set up Pango prerequisites */
 	font_desc = calitem->font_desc;
@@ -1052,8 +1051,6 @@ e_calendar_item_draw		(GnomeCanvasItem *canvas_item,
 		PANGO_PIXELS (pango_font_metrics_get_descent (font_metrics));
 	xthickness = style->xthickness;
 	ythickness = style->ythickness;
-	base_gc = style->base_gc[GTK_STATE_NORMAL];
-	bg_gc = style->bg_gc[GTK_STATE_NORMAL];
 
 	base = style->base[GTK_STATE_NORMAL];
 	bg = style->bg[GTK_STATE_NORMAL];
@@ -1164,7 +1161,6 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 	PangoFontMetrics *font_metrics;
 	PangoLayout *layout;
 	cairo_t *cr;
-	GdkColor fg;
 
 #if 0
 	g_print ("In e_calendar_item_draw_month: %i,%i %ix%i row:%i col:%i\n",
@@ -1172,7 +1168,7 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 #endif
 	item = GNOME_CANVAS_ITEM (calitem);
 	widget = GTK_WIDGET (item->canvas);
-	style = widget->style;
+	style = gtk_widget_get_style (widget);
 
 	cr = gdk_cairo_create (drawable);
 
@@ -1191,8 +1187,6 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 	ythickness = style->ythickness;
 	fg_gc = style->fg_gc[GTK_STATE_NORMAL];
 
-	fg = style->fg[GTK_STATE_NORMAL];
-
 	pango_font_metrics_unref (font_metrics);
 
 	/* Calculate the top-left position of the entire month display. */
@@ -1396,7 +1390,7 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 	GnomeCanvasItem *item;
 	GtkWidget *widget;
 	GtkStyle *style;
-	PangoFontDescription *font_desc, *wkfont_desc;
+	PangoFontDescription *font_desc;
 	GdkGC *fg_gc;
 	GdkColor *bg_color, *fg_color, *box_color;
 	struct tm today_tm;
@@ -1419,7 +1413,7 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 
 	item = GNOME_CANVAS_ITEM (calitem);
 	widget = GTK_WIDGET (item->canvas);
-	style = widget->style;
+	style = gtk_widget_get_style (widget);
 
 	cr = gdk_cairo_create (drawable);
 
@@ -1427,9 +1421,6 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 	font_desc = calitem->font_desc;
 	if (!font_desc)
 		font_desc = style->font_desc;
-	wkfont_desc = calitem->week_number_font_desc;
-	if (!wkfont_desc)
-		wkfont_desc = font_desc;
 	fg_gc = style->fg_gc[GTK_STATE_NORMAL];
 
 	pango_context = gtk_widget_get_pango_context (widget);
@@ -1561,7 +1552,11 @@ e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 					day_style = calitem->styles[(month_offset + 1) * 32 + day_num];
 
 				/* Get the colors & style to use for the day.*/
+#if GTK_CHECK_VERSION(2,19,7)
+				if ((gtk_widget_has_focus (GTK_WIDGET (item->canvas))) &&
+#else
 				if ((GTK_WIDGET_HAS_FOCUS(item->canvas)) &&
+#endif
 				    item->canvas->focused_item == item)
 					has_focus = TRUE;
 				else
@@ -1732,8 +1727,6 @@ e_calendar_item_get_week_number	(ECalendarItem *calitem,
 			g_date_add_days (&date, 7 - weekday);
 		else
 			g_date_subtract_days (&date, weekday);
-
-		weekday = g_date_get_weekday (&date) - 1;
 	}
 
 	/* Calculate the day of the year, from 0 to 365. */
@@ -1760,7 +1753,7 @@ e_calendar_item_get_week_number	(ECalendarItem *calitem,
    Since we are the only item we just return ourself and 0 for the distance.
    This is needed so that we get button/motion events. */
 static double
-e_calendar_item_point (GnomeCanvasItem *item, double x, double y,
+e_calendar_item_point (GnomeCanvasItem *item, gdouble x, gdouble y,
 			   gint cx, gint cy,
 			   GnomeCanvasItem **actual_item)
 {
@@ -1923,8 +1916,8 @@ e_calendar_item_event (GnomeCanvasItem *item, GdkEvent *event)
 }
 
 static void
-e_calendar_item_bounds (GnomeCanvasItem *item, double *x1, double *y1,
-			double *x2, double *y2)
+e_calendar_item_bounds (GnomeCanvasItem *item, gdouble *x1, gdouble *y1,
+			gdouble *x2, gdouble *y2)
 {
 	ECalendarItem *calitem;
 
@@ -1952,7 +1945,7 @@ e_calendar_item_recalc_sizes		(ECalendarItem *calitem)
 	PangoLayout *layout;
 
 	canvas_item = GNOME_CANVAS_ITEM (calitem);
-	style = GTK_WIDGET (canvas_item->canvas)->style;
+	style = gtk_widget_get_style (GTK_WIDGET (canvas_item->canvas));
 
 	if (!style)
 		return;
@@ -2062,7 +2055,7 @@ e_calendar_item_get_day_style		(ECalendarItem	*calitem,
 	GtkStyle *style;
 
 	widget = GTK_WIDGET (GNOME_CANVAS_ITEM (calitem)->canvas);
-	style = widget->style;
+	style = gtk_widget_get_style (widget);
 
 	*bg_color = NULL;
 	*fg_color = NULL;
@@ -2075,7 +2068,7 @@ e_calendar_item_get_day_style		(ECalendarItem	*calitem,
 		*box_color = &calitem->colors[E_CALENDAR_ITEM_COLOR_TODAY_BOX];
 
 	if (prev_or_next_month)
-		*fg_color = &style->mid[GTK_WIDGET_STATE (widget)];
+		*fg_color = &style->mid[gtk_widget_get_state (widget)];
 
 	if (selected) {
 		if (has_focus) {
@@ -2400,7 +2393,7 @@ e_calendar_item_convert_position_to_day	(ECalendarItem	*calitem,
 
 	item = GNOME_CANVAS_ITEM (calitem);
 	widget = GTK_WIDGET (item->canvas);
-	style = widget->style;
+	style = gtk_widget_get_style (widget);
 
 	font_desc = calitem->font_desc;
 	if (!font_desc)
@@ -3101,8 +3094,8 @@ e_calendar_item_get_selection		(ECalendarItem	*calitem,
 
 static void
 e_calendar_item_set_selection_if_emission (ECalendarItem	*calitem,
-					   GDate		*start_date,
-					   GDate		*end_date,
+					   const GDate		*start_date,
+					   const GDate		*end_date,
 					   gboolean emission)
 {
 	gint start_year, start_month, start_day;
@@ -3181,28 +3174,31 @@ e_calendar_item_set_selection_if_emission (ECalendarItem	*calitem,
 void
 e_calendar_item_style_set (GtkWidget *widget, ECalendarItem *calitem)
 {
+	GtkStyle *style;
 	GdkColor *color;
 
-	color = &widget->style->bg[GTK_STATE_SELECTED];
+	style = gtk_widget_get_style (widget);
+
+	color = &style->bg[GTK_STATE_SELECTED];
 	calitem->colors[E_CALENDAR_ITEM_COLOR_TODAY_BOX] = *color;
 
-	color = &widget->style->base[GTK_STATE_NORMAL];
+	color = &style->base[GTK_STATE_NORMAL];
 	calitem->colors[E_CALENDAR_ITEM_COLOR_SELECTION_FG] = *color;
 
-	color = &widget->style->bg[GTK_STATE_SELECTED];
+	color = &style->bg[GTK_STATE_SELECTED];
 	calitem->colors[E_CALENDAR_ITEM_COLOR_SELECTION_BG_FOCUSED] = *color;
 
-	color = &widget->style->fg[GTK_STATE_INSENSITIVE];
+	color = &style->fg[GTK_STATE_INSENSITIVE];
 	calitem->colors[E_CALENDAR_ITEM_COLOR_SELECTION_BG] = *color;
 
-	color = &widget->style->fg[GTK_STATE_INSENSITIVE];
+	color = &style->fg[GTK_STATE_INSENSITIVE];
 	calitem->colors[E_CALENDAR_ITEM_COLOR_PREV_OR_NEXT_MONTH_FG] = *color;
 }
 
 void
 e_calendar_item_set_selection (ECalendarItem	*calitem,
-			       GDate		*start_date,
-			       GDate		*end_date)
+			       const GDate	*start_date,
+			       const GDate	*end_date)
 {
 	/* If the user is in the middle of a selection, we must abort it. */
 	if (calitem->selecting) {
@@ -3376,13 +3372,16 @@ static void
 e_calendar_item_on_menu_item_activate	(GtkWidget	*menuitem,
 					 ECalendarItem	*calitem)
 {
+	GtkWidget *parent;
 	gint year, month_offset, month;
 	gpointer data;
 
-	data = g_object_get_data (G_OBJECT (menuitem->parent), "year");
+	parent = gtk_widget_get_parent (menuitem);
+	data = g_object_get_data (G_OBJECT (parent), "year");
 	year = GPOINTER_TO_INT (data);
 
-	data = g_object_get_data (G_OBJECT (menuitem->parent), "month_offset");
+	parent = gtk_widget_get_parent (menuitem);
+	data = g_object_get_data (G_OBJECT (parent), "month_offset");
 	month_offset = GPOINTER_TO_INT (data);
 
 	data = g_object_get_data (G_OBJECT (menuitem), "month");
