@@ -27,9 +27,7 @@
 
 #include <libgnomecanvas/gnome-canvas.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 /*
  * ECalendarItem - canvas item displaying a calendar.
@@ -43,7 +41,8 @@ extern "C" {
 #define E_CALENDAR_COLS_PER_MONTH	7
 
 /* Used to mark days as bold in e_calendar_item_mark_day(). */
-#define E_CALENDAR_ITEM_MARK_BOLD	1
+#define E_CALENDAR_ITEM_MARK_BOLD	(1 << 0)
+#define E_CALENDAR_ITEM_MARK_ITALIC     (1 << 1)
 
 /*
  * These are the padding sizes between various pieces of the calendar.
@@ -71,7 +70,6 @@ extern "C" {
 #define	E_CALENDAR_ITEM_XPAD_BEFORE_CELLS		1
 #define	E_CALENDAR_ITEM_XPAD_AFTER_CELLS		4
 
-
 /* These index our colors array. */
 typedef enum
 {
@@ -103,6 +101,7 @@ typedef void (*ECalendarItemStyleCallback)   (ECalendarItem	*calitem,
 					      GdkColor	       **fg_color,
 					      GdkColor	       **box_color,
 					      gboolean		*bold,
+					      gboolean		*italic,
 					      gpointer		 data);
 
 /* The type of the callback function optionally used to get the current time.
@@ -110,7 +109,6 @@ typedef void (*ECalendarItemStyleCallback)   (ECalendarItem	*calitem,
 typedef struct tm (*ECalendarItemGetTimeCallback) (ECalendarItem *calitem,
 						   gpointer	  data);
 
-
 #define E_CALENDAR_ITEM(obj)     (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
         e_calendar_item_get_type (), ECalendarItem))
 #define E_CALENDAR_ITEM_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k),\
@@ -265,110 +263,112 @@ struct _ECalendarItemClass
 	void (* selection_preview_changed)	(ECalendarItem *calitem);
 };
 
-
-GType    e_calendar_item_get_type		(void);
+GType	e_calendar_item_get_type		(void);
 
 /* FIXME: months are 0-11 throughout, but 1-12 may be better. */
 
-void	 e_calendar_item_get_first_month	(ECalendarItem	*calitem,
-						 gint		*year,
-						 gint		*month);
-void	 e_calendar_item_set_first_month	(ECalendarItem	*calitem,
-						 gint		 year,
-						 gint		 month);
+void	e_calendar_item_get_first_month		(ECalendarItem *calitem,
+						 gint *year,
+						 gint *month);
+void	e_calendar_item_set_first_month		(ECalendarItem *calitem,
+						 gint year,
+						 gint month);
 
 /* Get the maximum number of days selectable */
-gint     e_calendar_item_get_max_days_sel       (ECalendarItem	*calitem);
+gint	e_calendar_item_get_max_days_sel	(ECalendarItem *calitem);
 
 /* Set the maximum number of days selectable */
-void	 e_calendar_item_set_max_days_sel       (ECalendarItem	*calitem,
-						 gint            days);
+void	e_calendar_item_set_max_days_sel	(ECalendarItem *calitem,
+						 gint days);
 
 /* Get the maximum number of days selectable */
-gint     e_calendar_item_get_days_start_week_sel(ECalendarItem	*calitem);
+gint	e_calendar_item_get_days_start_week_sel	(ECalendarItem *calitem);
 
 /* Set the maximum number of days selectable */
-void	 e_calendar_item_set_days_start_week_sel(ECalendarItem	*calitem,
-						 gint            days);
+void	e_calendar_item_set_days_start_week_sel	(ECalendarItem *calitem,
+						 gint days);
 
 /* Set the maximum number of days before whole weeks are selected */
-gboolean e_calendar_item_get_display_popup      (ECalendarItem	*calitem);
+gboolean
+	e_calendar_item_get_display_popup	(ECalendarItem *calitem);
 
 /* Get the maximum number of days before whole weeks are selected */
-void	 e_calendar_item_set_display_popup      (ECalendarItem	*calitem,
-						 gboolean        display);
+void	e_calendar_item_set_display_popup	(ECalendarItem *calitem,
+						 gboolean display);
 
 /* Gets the range of dates actually shown. Months are 0 to 11.
    This also includes the last days of the previous month and the first days
    of the following month, which are normally shown in gray.
    It returns FALSE if no dates are currently shown. */
-gboolean e_calendar_item_get_date_range		(ECalendarItem	*calitem,
-						 gint		*start_year,
-						 gint		*start_month,
-						 gint		*start_day,
-						 gint		*end_year,
-						 gint		*end_month,
-						 gint		*end_day);
+gboolean
+	e_calendar_item_get_date_range		(ECalendarItem *calitem,
+						 gint *start_year,
+						 gint *start_month,
+						 gint *start_day,
+						 gint *end_year,
+						 gint *end_month,
+						 gint *end_day);
 
 /* Returns the selected date range. It returns FALSE if no days are currently
    selected. */
-gboolean e_calendar_item_get_selection		(ECalendarItem	*calitem,
-						 GDate		*start_date,
-						 GDate		*end_date);
+gboolean
+	e_calendar_item_get_selection		(ECalendarItem *calitem,
+						 GDate *start_date,
+						 GDate *end_date);
 /* Sets the selected date range, and changes the date range shown so at least
    the start of the selection is shown. If start_date is NULL it clears the
    selection. */
-void	 e_calendar_item_set_selection		(ECalendarItem	*calitem,
-						 GDate		*start_date,
-						 GDate		*end_date);
+void	e_calendar_item_set_selection		(ECalendarItem *calitem,
+						 const GDate *start_date,
+						 const GDate *end_date);
 
 /* Marks a particular day. Passing E_CALENDAR_ITEM_MARK_BOLD as the day style
    will result in the day being shown as bold by default. The style callback
    could support more day_styles, or the style callback could determine the
    colors itself, without needing to mark days. */
-void	 e_calendar_item_clear_marks		(ECalendarItem	*calitem);
-void	 e_calendar_item_mark_day		(ECalendarItem	*calitem,
-						 gint		 year,
-						 gint		 month,
-						 gint		 day,
-						 guint8		 day_style);
+void	e_calendar_item_clear_marks		(ECalendarItem *calitem);
+void	e_calendar_item_mark_day		(ECalendarItem *calitem,
+						 gint year,
+						 gint month,
+						 gint day,
+						 guint8 day_style,
+						 gboolean add_day_style);
 
 /* Mark a range of days. Any days outside the currently shown range are
    ignored. */
-void	 e_calendar_item_mark_days		(ECalendarItem	*calitem,
-						 gint		 start_year,
-						 gint		 start_month,
-						 gint		 start_day,
-						 gint		 end_year,
-						 gint		 end_month,
-						 gint		 end_day,
-						 guint8		 day_style);
+void	e_calendar_item_mark_days		(ECalendarItem *calitem,
+						 gint start_year,
+						 gint start_month,
+						 gint start_day,
+						 gint end_year,
+						 gint end_month,
+						 gint end_day,
+						 guint8 day_style,
+						 gboolean add_day_style);
 
 /* Sets the function to call to get the colors to use for a particular day. */
-void	 e_calendar_item_set_style_callback	(ECalendarItem	*calitem,
+void	e_calendar_item_set_style_callback	(ECalendarItem *calitem,
 						 ECalendarItemStyleCallback cb,
-						 gpointer	 data,
+						 gpointer data,
 						 GDestroyNotify  destroy);
 
 /* Sets a callback to use to get the current time. This is useful if the
    application needs to use its own timezone data rather than rely on the
    Unix timezone. */
-void	 e_calendar_item_set_get_time_callback	(ECalendarItem	*calitem,
+void	e_calendar_item_set_get_time_callback	(ECalendarItem *calitem,
 						 ECalendarItemGetTimeCallback cb,
-						 gpointer	 data,
+						 gpointer data,
 						 GDestroyNotify  destroy);
-void e_calendar_item_normalize_date	(ECalendarItem	*calitem,
-					 gint		*year,
-					 gint		*month);
-gint e_calendar_item_get_week_number	(ECalendarItem *calitem,
-					 gint		day,
-					 gint		month,
-					 gint		year);
-void e_calendar_item_style_set (GtkWidget *widget, ECalendarItem *calitem);
+void	e_calendar_item_normalize_date		(ECalendarItem *calitem,
+						 gint *year,
+						 gint *month);
+gint	e_calendar_item_get_week_number		(ECalendarItem *calitem,
+						 gint day,
+						 gint month,
+						 gint year);
+void	e_calendar_item_style_set		(GtkWidget *widget,
+						 ECalendarItem *calitem);
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* _E_CALENDAR_ITEM_H_ */
