@@ -383,16 +383,32 @@ e_cell_date_edit_get_property		(GObject	*object,
 
 	switch (property_id) {
 	case PROP_SHOW_TIME:
+#if GTK_CHECK_VERSION(2,19,7)
+		g_value_set_boolean (value, gtk_widget_get_visible (ecde->time_entry));
+#else
 		g_value_set_boolean (value, GTK_WIDGET_VISIBLE (ecde->time_entry));
+#endif
 		return;
 	case PROP_SHOW_NOW_BUTTON:
+#if GTK_CHECK_VERSION(2,19,7)
+		g_value_set_boolean (value, gtk_widget_get_visible (ecde->now_button));
+#else
 		g_value_set_boolean (value, GTK_WIDGET_VISIBLE (ecde->now_button));
+#endif
 		return;
 	case PROP_SHOW_TODAY_BUTTON:
+#if GTK_CHECK_VERSION(2,19,7)
+		g_value_set_boolean (value, gtk_widget_get_visible (ecde->today_button));
+#else
 		g_value_set_boolean (value, GTK_WIDGET_VISIBLE (ecde->today_button));
+#endif
 		return;
 	case PROP_ALLOW_NO_DATE_SET:
+#if GTK_CHECK_VERSION(2,19,7)
+		g_value_set_boolean (value, gtk_widget_get_visible (ecde->none_button));
+#else
 		g_value_set_boolean (value, GTK_WIDGET_VISIBLE (ecde->none_button));
+#endif
 		return;
 	case PROP_USE_24_HOUR_FORMAT:
 		g_value_set_boolean (value, ecde->use_24_hour_format);
@@ -644,7 +660,7 @@ e_cell_date_edit_get_popup_pos		(ECellDateEdit	*ecde,
 	GtkWidget *canvas = GTK_WIDGET (GNOME_CANVAS_ITEM (eti)->canvas);
 	GtkRequisition popup_requisition;
 	gint avail_height, screen_width, column_width, row_height;
-	double x1, y1, wx, wy;
+	gdouble x1, y1, wx, wy;
 
 	gdk_window_get_origin (canvas->window, x, y);
 
