@@ -183,22 +183,30 @@ e_table_header_item_get_height (ETableHeaderItem *ethi)
 }
 
 static void
-ethi_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, gint flags)
+ethi_update (GnomeCanvasItem *item,
+             gdouble *affine,
+             ArtSVP *clip_path,
+             gint flags)
 {
 	ETableHeaderItem *ethi = E_TABLE_HEADER_ITEM (item);
 
-	double   i2c [6];
+	gdouble   i2c [6];
 	ArtPoint c1, c2, i1, i2;
 
 	if (GNOME_CANVAS_ITEM_CLASS (ethi_parent_class)->update)
-		(*GNOME_CANVAS_ITEM_CLASS (ethi_parent_class)->update)(item, affine, clip_path, flags);
+		GNOME_CANVAS_ITEM_CLASS (ethi_parent_class)->update (
+			item, affine, clip_path, flags);
 
 	if (ethi->sort_info)
-		ethi->group_indent_width = e_table_sort_info_grouping_get_count(ethi->sort_info) * GROUP_INDENT;
+		ethi->group_indent_width =
+			e_table_sort_info_grouping_get_count (ethi->sort_info)
+			* GROUP_INDENT;
 	else
 		ethi->group_indent_width = 0;
 
-	ethi->width = e_table_header_total_width (ethi->eth) + ethi->group_indent_width;
+	ethi->width =
+		e_table_header_total_width (ethi->eth) +
+		ethi->group_indent_width;
 
 	i1.x = i1.y = 0;
 	i2.x = ethi->width;
@@ -213,7 +221,10 @@ ethi_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, gint flag
 	    item->x2 != c2.x ||
 	    item->y2 != c2.y)
 		{
-			gnome_canvas_request_redraw (item->canvas, item->x1, item->y1, item->x2, item->y2);
+			gnome_canvas_request_redraw (
+				item->canvas,
+				item->x1, item->y1,
+				item->x2, item->y2);
 			item->x1 = c1.x;
 			item->y1 = c1.y;
 			item->x2 = c2.x;
@@ -348,7 +359,7 @@ ethi_set_property (GObject *object,
 		ethi->group_info_changed_id =
 			g_signal_connect (
 				ethi->sort_info, "group_info_changed",
-				G_CALLBACK(ethi_sort_info_changed), ethi);
+				G_CALLBACK (ethi_sort_info_changed), ethi);
 		break;
 	case PROP_TABLE:
 		if (g_value_get_object (value))
@@ -508,13 +519,21 @@ ethi_add_drop_marker (ETableHeaderItem *ethi, gint col, gboolean recreate)
 		GTK_WIDGET (GNOME_CANVAS_ITEM (ethi)->canvas)->window,
 		&rx, &ry);
 
-	rx -= gtk_layout_get_hadjustment (GTK_LAYOUT (GNOME_CANVAS_ITEM (ethi)->canvas))->value;
-	ry -= gtk_layout_get_vadjustment (GTK_LAYOUT (GNOME_CANVAS_ITEM (ethi)->canvas))->value;
+	rx -= gtk_layout_get_hadjustment (
+		GTK_LAYOUT (GNOME_CANVAS_ITEM (ethi)->canvas))->value;
+	ry -= gtk_layout_get_vadjustment (
+		GTK_LAYOUT (GNOME_CANVAS_ITEM (ethi)->canvas))->value;
 
-	gtk_window_move (GTK_WINDOW (arrow_down), rx + x - ARROW_PTR, ry - ARROW_DOWN_HEIGHT);
+	gtk_window_move (
+		GTK_WINDOW (arrow_down),
+		rx + x - ARROW_PTR,
+		ry - ARROW_DOWN_HEIGHT);
 	gtk_widget_show_all (arrow_down);
 
-	gtk_window_move (GTK_WINDOW (arrow_up), rx + x - ARROW_PTR, ry + ethi->height);
+	gtk_window_move (
+		GTK_WINDOW (arrow_up),
+		rx + x - ARROW_PTR,
+		ry + ethi->height);
 	gtk_widget_show_all (arrow_up);
 }
 
@@ -526,7 +545,7 @@ static gchar gray50_bits [] = {
 static void
 ethi_add_destroy_marker (ETableHeaderItem *ethi)
 {
-	double x1;
+	gdouble x1;
 
 	if (ethi->remove_item)
 		gtk_object_destroy (GTK_OBJECT (ethi->remove_item));
@@ -535,7 +554,7 @@ ethi_add_destroy_marker (ETableHeaderItem *ethi)
 		ethi->stipple = gdk_bitmap_create_from_data  (
 			NULL, gray50_bits, gray50_width, gray50_height);
 
-	x1 = (double) e_table_header_col_diff (ethi->eth, 0, ethi->drag_col);
+	x1 = (gdouble) e_table_header_col_diff (ethi->eth, 0, ethi->drag_col);
 	if (ethi->drag_col > 0)
 		x1 += ethi->group_indent_width;
 
@@ -543,11 +562,11 @@ ethi_add_destroy_marker (ETableHeaderItem *ethi)
 		GNOME_CANVAS_GROUP (GNOME_CANVAS_ITEM (ethi)->canvas->root),
 		gnome_canvas_rect_get_type (),
 		"x1", x1 + 1,
-		"y1", (double) 1,
-		"x2", (double) x1 + e_table_header_col_diff (
+		"y1", (gdouble) 1,
+		"x2", (gdouble) x1 + e_table_header_col_diff (
 			ethi->eth, ethi->drag_col, ethi->drag_col+1) - 2,
 
-		"y2", (double) ethi->height - 2,
+		"y2", (gdouble) ethi->height - 2,
 		"fill_color", "red",
 		"fill_stipple", ethi->stipple,
 		NULL);
@@ -582,16 +601,13 @@ moved (ETableHeaderItem *ethi, guint col, guint model_col)
 #endif
 
 static void
-do_drag_motion(ETableHeaderItem *ethi,
-	       GdkDragContext *context,
-	       gint x,
-	       gint y,
-	       guint time,
-	       gboolean recreate)
+do_drag_motion (ETableHeaderItem *ethi,
+                GdkDragContext *context,
+                gint x,
+                gint y,
+                guint time,
+                gboolean recreate)
 {
-	d(g_print("In do_drag_motion\n"));
-	d(g_print("x = %d, y = %d, ethi->width = %d, ethi->height = %d\n", x, y, ethi->width, ethi->height));
-
 	if ((x >= 0) && (x <= (ethi->width)) &&
 	    (y >= 0) && (y <= (ethi->height))) {
 		gint col;
@@ -630,7 +646,7 @@ scroll_timeout (gpointer data)
 	ETableHeaderItem *ethi = data;
 	gint dx = 0;
 	GtkAdjustment *h, *v;
-	double value;
+	gdouble value;
 
 	if (ethi->scroll_direction & ET_SCROLL_RIGHT)
 		dx += 20;
@@ -690,7 +706,8 @@ context_destroyed (gpointer data)
 }
 
 static void
-context_connect (ETableHeaderItem *ethi, GdkDragContext *context)
+context_connect (ETableHeaderItem *ethi,
+                 GdkDragContext *context)
 {
 	if (g_dataset_get_data (context, "e-table-header-item") == NULL) {
 		g_object_ref (ethi);
@@ -699,9 +716,12 @@ context_connect (ETableHeaderItem *ethi, GdkDragContext *context)
 }
 
 static gboolean
-ethi_drag_motion (GtkWidget *widget, GdkDragContext *context,
-		  gint x, gint y, guint time,
-		  ETableHeaderItem *ethi)
+ethi_drag_motion (GtkWidget *widget,
+                  GdkDragContext *context,
+                  gint x,
+                  gint y,
+                  guint time,
+                  ETableHeaderItem *ethi)
 {
 	gchar *droptype, *headertype;
 	guint direction = 0;
@@ -719,8 +739,6 @@ ethi_drag_motion (GtkWidget *widget, GdkDragContext *context,
 
 	g_free (headertype);
 
-	d(g_print ("y = %d, widget->allocation.y = %d, GTK_LAYOUT (widget)->vadjustment->value = %f\n", y, widget->allocation.y, GTK_LAYOUT (widget)->vadjustment->value));
-
 	if (x < 20)
 		direction |= ET_SCROLL_LEFT;
 	if (x > widget->allocation.width - 20)
@@ -748,7 +766,9 @@ ethi_drag_motion (GtkWidget *widget, GdkDragContext *context,
 }
 
 static void
-ethi_drag_end (GtkWidget *canvas, GdkDragContext *context, ETableHeaderItem *ethi)
+ethi_drag_end (GtkWidget *canvas,
+               GdkDragContext *context,
+               ETableHeaderItem *ethi)
 {
 	ethi_remove_drop_marker (ethi);
 	ethi_remove_destroy_marker (ethi);
@@ -857,7 +877,10 @@ ethi_drag_drop (GtkWidget *canvas,
 }
 
 static void
-ethi_drag_leave (GtkWidget *widget, GdkDragContext *context, guint time, ETableHeaderItem *ethi)
+ethi_drag_leave (GtkWidget *widget,
+                 GdkDragContext *context,
+                 guint time,
+                 ETableHeaderItem *ethi)
 {
 	ethi_remove_drop_marker (ethi);
 	if (ethi->drag_col != -1)
@@ -881,11 +904,12 @@ ethi_realize (GnomeCanvasItem *item)
 	/*
 	 * Now, configure DnD
 	 */
-	ethi_drop_types[0].target = g_strdup_printf("%s-%s", ethi_drop_types[0].target, ethi->dnd_code);
-	gtk_drag_dest_set (GTK_WIDGET (item->canvas), 0,
-			   ethi_drop_types, G_N_ELEMENTS (ethi_drop_types),
-			   GDK_ACTION_MOVE);
-	g_free(ethi_drop_types[0].target);
+	ethi_drop_types[0].target = g_strdup_printf (
+		"%s-%s", ethi_drop_types[0].target, ethi->dnd_code);
+	gtk_drag_dest_set (
+		GTK_WIDGET (item->canvas), 0, ethi_drop_types,
+		G_N_ELEMENTS (ethi_drop_types), GDK_ACTION_MOVE);
+	g_free (ethi_drop_types[0].target);
 
 	/* Drop signals */
 	ethi->drag_motion_id = g_signal_connect (item->canvas, "drag_motion",
@@ -935,7 +959,12 @@ ethi_unrealize (GnomeCanvasItem *item)
 }
 
 static void
-ethi_draw (GnomeCanvasItem *item, GdkDrawable *drawable, gint x, gint y, gint width, gint height)
+ethi_draw (GnomeCanvasItem *item,
+           GdkDrawable *drawable,
+           gint x,
+           gint y,
+           gint width,
+           gint height)
 {
 	ETableHeaderItem *ethi = E_TABLE_HEADER_ITEM (item);
 	GnomeCanvas *canvas = item->canvas;
@@ -971,6 +1000,7 @@ ethi_draw (GnomeCanvasItem *item, GdkDrawable *drawable, gint x, gint y, gint wi
 	x2 += ethi->group_indent_width;
 	for (col = 0; col < cols; col++, x1 = x2) {
 		ETableCol *ecol = e_table_header_get_column (ethi->eth, col);
+		GtkStateType state;
 		gint col_width;
 
 		col_width = ecol->width;
@@ -986,9 +1016,11 @@ ethi_draw (GnomeCanvasItem *item, GdkDrawable *drawable, gint x, gint y, gint wi
 		if (x2 <= x1)
 			continue;
 
+		state = gtk_widget_get_state (GTK_WIDGET (canvas));
+
 		e_table_header_draw_button (drawable, ecol,
 					    GTK_WIDGET (canvas)->style,
-					    GTK_WIDGET_STATE (canvas),
+					    state,
 					    GTK_WIDGET (canvas),
 					    x1 - x, -y,
 					    width, height,
@@ -1001,7 +1033,7 @@ ethi_draw (GnomeCanvasItem *item, GdkDrawable *drawable, gint x, gint y, gint wi
 }
 
 static double
-ethi_point (GnomeCanvasItem *item, double x, double y, gint cx, gint cy,
+ethi_point (GnomeCanvasItem *item, gdouble x, gdouble y, gint cx, gint cy,
 	    GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
@@ -1016,7 +1048,10 @@ ethi_point (GnomeCanvasItem *item, double x, double y, gint cx, gint cy,
  * then the ETableCol that actually contains this point is returned here
  */
 static gboolean
-is_pointer_on_division (ETableHeaderItem *ethi, gint pos, gint *the_total, gint *return_col)
+is_pointer_on_division (ETableHeaderItem *ethi,
+                        gint pos,
+                        gint *the_total,
+                        gint *return_col)
 {
 	const gint cols = e_table_header_count (ethi->eth);
 	gint col, total;
@@ -1122,6 +1157,7 @@ ethi_start_drag (ETableHeaderItem *ethi, GdkEvent *event)
 	GtkWidget *widget = GTK_WIDGET (GNOME_CANVAS_ITEM (ethi)->canvas);
 	GtkTargetList *list;
 	GdkDragContext *context;
+	GtkStateType state;
 	ETableCol *ecol;
 	gint col_width;
 	GdkPixmap *pixmap;
@@ -1178,10 +1214,12 @@ ethi_start_drag (ETableHeaderItem *ethi, GdkEvent *event)
 	col_width = ecol->width;
 	pixmap = gdk_pixmap_new (widget->window, col_width, ethi->height, -1);
 
+	state = gtk_widget_get_state (widget);
+
 	e_table_header_draw_button (
 		pixmap, ecol,
 		widget->style,
-		GTK_WIDGET_STATE (widget),
+		state,
 		widget,
 		0, 0,
 		col_width, ethi->height,
@@ -1466,37 +1504,62 @@ free_popup_info (GtkWidget *w, EthiHeaderInfo *info)
 /* Bit 2 is disabled if not "sortable". */
 /* Bit 4 is disabled if we don't have a pointer to our table object. */
 static EPopupMenu ethi_context_menu [] = {
-	E_POPUP_ITEM (N_("Sort _Ascending"), G_CALLBACK(ethi_popup_sort_ascending),  2),
-	E_POPUP_ITEM (N_("Sort _Descending"), G_CALLBACK(ethi_popup_sort_descending), 2),
-	E_POPUP_ITEM (N_("_Unsort"), G_CALLBACK(ethi_popup_unsort),          0),
+	E_POPUP_ITEM (
+		N_("Sort _Ascending"),
+		G_CALLBACK (ethi_popup_sort_ascending), 2),
+	E_POPUP_ITEM (
+		N_("Sort _Descending"),
+		G_CALLBACK (ethi_popup_sort_descending), 2),
+	E_POPUP_ITEM (
+		N_("_Unsort"), G_CALLBACK (ethi_popup_unsort), 0),
 	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("Group By This _Field"), G_CALLBACK(ethi_popup_group_field),     16),
-	E_POPUP_ITEM (N_("Group By _Box"), G_CALLBACK(ethi_popup_group_box),       128),
+	E_POPUP_ITEM (
+		N_("Group By This _Field"),
+		G_CALLBACK (ethi_popup_group_field), 16),
+	E_POPUP_ITEM (
+		N_("Group By _Box"),
+		G_CALLBACK (ethi_popup_group_box), 128),
 	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("Remove This _Column"), G_CALLBACK(ethi_popup_remove_column),   8),
-	E_POPUP_ITEM (N_("Add a C_olumn..."), G_CALLBACK(ethi_popup_field_chooser),   0),
+	E_POPUP_ITEM (
+		N_("Remove This _Column"),
+		G_CALLBACK (ethi_popup_remove_column), 8),
+	E_POPUP_ITEM (
+		N_("Add a C_olumn..."),
+		G_CALLBACK (ethi_popup_field_chooser), 0),
 	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("A_lignment"), G_CALLBACK(ethi_popup_alignment),       128),
-	E_POPUP_ITEM (N_("B_est Fit"), G_CALLBACK(ethi_popup_best_fit),        2),
-	E_POPUP_ITEM (N_("Format Column_s..."), G_CALLBACK(ethi_popup_format_columns),  128),
+	E_POPUP_ITEM (
+		N_("A_lignment"),
+		G_CALLBACK (ethi_popup_alignment), 128),
+	E_POPUP_ITEM (
+		N_("B_est Fit"),
+		G_CALLBACK (ethi_popup_best_fit), 2),
+	E_POPUP_ITEM (
+		N_("Format Column_s..."),
+		G_CALLBACK (ethi_popup_format_columns), 128),
 	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("Custo_mize Current View..."), G_CALLBACK(ethi_popup_customize_view),  4),
+	E_POPUP_ITEM (
+		N_("Custo_mize Current View..."),
+		G_CALLBACK (ethi_popup_customize_view), 4),
 	E_POPUP_TERMINATOR
 };
 
 static void
 sort_by_id (GtkWidget *menu_item, ETableHeaderItem *ethi)
 {
-	gint col = GPOINTER_TO_INT (g_object_get_data(G_OBJECT (menu_item), "col-number"));
 	ETableCol *ecol;
 	gboolean clearfirst;
+	gint col;
 
+	col = GPOINTER_TO_INT (g_object_get_data (
+		G_OBJECT (menu_item), "col-number"));
 	ecol = e_table_header_get_column (ethi->full_header, col);
 	clearfirst = e_table_sort_info_sorting_get_count (ethi->sort_info) > 1;
 
-	if (!clearfirst && ecol && e_table_sort_info_sorting_get_count (ethi->sort_info) == 1) {
-		ETableSortColumn column = e_table_sort_info_sorting_get_nth(ethi->sort_info, 0);
+	if (!clearfirst && ecol &&
+		e_table_sort_info_sorting_get_count (ethi->sort_info) == 1) {
+		ETableSortColumn column;
 
+		column = e_table_sort_info_sorting_get_nth(ethi->sort_info, 0);
 		clearfirst = ecol->sortable && ecol->col_idx != column.column;
 	}
 
@@ -1516,7 +1579,6 @@ static void
 ethi_header_context_menu (ETableHeaderItem *ethi, GdkEventButton *event)
 {
 	EthiHeaderInfo *info = g_new (EthiHeaderInfo, 1);
-	ETableCol *col;
 	GtkMenu *popup;
 	gint ncol, sort_count, sort_col;
 	GtkWidget *menu_item, *sub_menu;
@@ -1526,7 +1588,6 @@ ethi_header_context_menu (ETableHeaderItem *ethi, GdkEventButton *event)
 
 	info->ethi = ethi;
 	info->col = ethi_find_col_by_x (ethi, event->x);
-	col = e_table_header_get_column (ethi->eth, info->col);
 
 	popup = e_popup_menu_create_with_domain (ethi_context_menu,
 						 1 +
@@ -1576,11 +1637,15 @@ ethi_header_context_menu (ETableHeaderItem *ethi, GdkEventButton *event)
 			continue;
 
 		if (ncol == sort_col) {
-			text = g_strdup_printf("%s (%s)", ethi->full_header->columns[ncol]->text, ascending ? _("Ascending"):_("Descending"));
+			text = g_strdup_printf (
+				"%s (%s)",
+				ethi->full_header->columns[ncol]->text,
+				ascending ? _("Ascending"):_("Descending"));
 			menu_item = gtk_check_menu_item_new_with_label (text);
 			g_free (text);
 		} else
-			menu_item = gtk_check_menu_item_new_with_label (ethi->full_header->columns[ncol]->text);
+			menu_item = gtk_check_menu_item_new_with_label (
+				ethi->full_header->columns[ncol]->text);
 
 		gtk_widget_show (menu_item);
 		gtk_menu_shell_prepend (GTK_MENU_SHELL (sub_menu), menu_item);
@@ -1628,7 +1693,7 @@ ethi_change_sort_state (ETableHeaderItem *ethi, ETableCol *col)
 		ETableSortColumn column = e_table_sort_info_grouping_get_nth(ethi->sort_info, i);
 		if (model_col == column.column || model_col == -1) {
 			gint ascending = column.ascending;
-			ascending = ! ascending;
+			ascending = !ascending;
 			column.ascending = ascending;
 			e_table_sort_info_grouping_set_nth(ethi->sort_info, i, column);
 			found = TRUE;
@@ -1802,7 +1867,8 @@ ethi_event (GnomeCanvasItem *item, GdkEvent *e)
 		} else if (was_maybe_drag && ethi->sort_info) {
 			ETableCol *ecol;
 
-			ecol = e_table_header_get_column (ethi->eth, ethi_find_col_by_x (ethi, e->button.x));
+			col = ethi_find_col_by_x (ethi, e->button.x);
+			ecol = e_table_header_get_column (ethi->eth, col);
 			ethi_change_sort_state (ethi, ecol);
 		}
 
